% Auto-generated chapter 2 for muslim
% Hadiths in this chapter: 143

\hadithdefcmd{muslim}{534}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبَانٌ، حَدَّثَنَا يَحْيَى، أَنَّ زَيْدًا، حَدَّثَهُ أَنَّ أَبَا سَلاَّمٍ حَدَّثَهُ عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الطُّهُورُ شَطْرُ الإِيمَانِ وَالْحَمْدُ لِلَّهِ تَمْلأُ الْمِيزَانَ ‏.‏ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ تَمْلآنِ - أَوْ تَمْلأُ - مَا بَيْنَ السَّمَوَاتِ وَالأَرْضِ وَالصَّلاَةُ نُورٌ وَالصَّدَقَةُ بُرْهَانٌ وَالصَّبْرُ ضِيَاءٌ وَالْقُرْآنُ حُجَّةٌ لَكَ أَوْ عَلَيْكَ كُلُّ النَّاسِ يَغْدُو فَبَائِعٌ نَفْسَهُ فَمُعْتِقُهَا أَوْ مُوبِقُهَا ‏"‏ ‏.‏\hadithno{534}\hadithtrans{Abu Malik at-Ash'ari reported:The Messenger of Allah (ﷺ) said: Cleanliness is half of faith and al-Hamdu Lillah (all praise and gratitude is for Allah alone) fills the scale, and Subhan Allah (Glory be to Allah) and al-Hamdu Lillah fill up what is between the heavens and the earth, and prayer is a light, and charity is proof (of one's faith) and endurance is a brightness and the Holy Qur'an is a proof on your behalf or against you. All men go out early in the morning and sell themselves, thereby setting themselves free or destroying themselves}}
\hadithdefcmd{muslim}{535}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لِسَعِيدٍ - قَالُوا حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، قَالَ دَخَلَ عَبْدُ اللَّهِ بْنُ عُمَرَ عَلَى ابْنِ عَامِرٍ يَعُودُهُ وَهُوَ مَرِيضٌ فَقَالَ أَلاَ تَدْعُو اللَّهَ لِي يَا ابْنَ عُمَرَ ‏.‏ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْبَلُ صَلاَةٌ بِغَيْرِ طُهُورٍ وَلاَ صَدَقَةٌ مِنْ غُلُولٍ ‏"‏ ‏.‏ وَكُنْتَ عَلَى الْبَصْرَةِ ‏.‏\hadithno{535}\hadithtrans{It was narrated from Simak bin Harb, that Mus'ab bin Sa'd said:'" 'Abdullah bin 'Umar came to visit Ibn 'Amir when he was sick and he said: 'Won't you supplicate to Allah for me, O Ibn 'Umar ?' He said: 'I heard the Messenger of Allah (ﷺ) say: "No Salat is accepted without Wudu' (purification), and no charity (is accepted) that comes from Ghulul [1] " and you were the governor of Al-Basrah.' " [1] Goods pilfered from the spoils of war prior to their authorized distribution}}
\hadithdefcmd{muslim}{536}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، قَالَ أَبُو بَكْرٍ وَوَكِيعٌ عَنْ إِسْرَائِيلَ، كُلُّهُمْ عَنْ سِمَاكِ بْنِ حَرْبٍ، بِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{536}\hadithtrans{A hadith like this is narrated from the Apostle (ﷺ) with the same chain of transmitters by Muhammad b. Muthanna, Ibn Bashshar, Muhammad b. Ja'far, Shu'ba}}
\hadithdefcmd{muslim}{537}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، حَدَّثَنَا مَعْمَرُ بْنُ رَاشِدٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَخِي وَهْبِ بْنِ مُنَبِّهٍ قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْبَلُ صَلاَةُ أَحَدِكُمْ إِذَا أَحْدَثَ حَتَّى يَتَوَضَّأَ ‏"‏ ‏.‏\hadithno{537}\hadithtrans{Hammam b. Munabbih who is the brother of Wahb b. Munabbih said:This is what has been transmitted to us by Abu Huraira from Muhammad, the Messenger of Allah (ﷺ) and then narrated a hadith out of them and observed that the Messenger of Allah (ﷺ) said: The prayer of none amongst you would be accepted in a state of impurity until he performs ablution}}
\hadithdefcmd{muslim}{538}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ سَرْحٍ وَحَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَطَاءَ بْنَ يَزِيدَ اللَّيْثِيَّ، أَخْبَرَهُ أَنَّ حُمْرَانَ مَوْلَى عُثْمَانَ أَخْبَرَهُ أَنَّ عُثْمَانَ بْنَ عَفَّانَ - رضى الله عنه - دَعَا بِوَضُوءٍ فَتَوَضَّأَ فَغَسَلَ كَفَّيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ مَضْمَضَ وَاسْتَنْثَرَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى إِلَى الْمِرْفَقِ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ يَدَهُ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ مَسَحَ رَأْسَهُ ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى إِلَى الْكَعْبَيْنِ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ الْيُسْرَى مِثْلَ ذَلِكَ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ قَامَ فَرَكَعَ رَكْعَتَيْنِ لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَكَانَ عُلَمَاؤُنَا يَقُولُونَ هَذَا الْوُضُوءُ أَسْبَغُ مَا يَتَوَضَّأُ بِهِ أَحَدٌ لِلصَّلاَةِ ‏.‏\hadithno{538}\hadithtrans{Humran, the freed slave of 'Uthman, said:Uthman b. 'Affan called for ablution water and this is how he performed the ablution. He washed his hands thrice. He then rinsed his mouth and cleaned his nose with water (three times). He then washed his face three times, then washed his right arm up to the elbow three times, then washed his left arm like that, then wiped his head; then washed his right foot up to the ankle three times, then washed his left foot like that, and then said: I saw the Messenger of Allah (ﷺ) perform ablution like this ablution of mine. Then the Messenger of Allah (ﷺ) said: He who performs ablution like this ablution of mine and then stood up (for prayer) and offered two rak'ahs of prayer without allowing his thoughts to be distracted, all his previous sins are expiated. Ibn Shihab said: Our scholars remarked: This is the most complete of the ablutions performed for prayer}}
\hadithdefcmd{muslim}{539}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ أَنَّهُ رَأَى عُثْمَانَ دَعَا بِإِنَاءٍ فَأَفْرَغَ عَلَى كَفَّيْهِ ثَلاَثَ مِرَارٍ فَغَسَلَهُمَا ثُمَّ أَدْخَلَ يَمِينَهُ فِي الإِنَاءِ فَمَضْمَضَ وَاسْتَنْثَرَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثَ مَرَّاتٍ وَيَدَيْهِ إِلَى الْمِرْفَقَيْنِ ثَلاَثَ مَرَّاتٍ ثُمَّ مَسَحَ بِرَأْسِهِ ثُمَّ غَسَلَ رِجْلَيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ نَحْوَ وُضُوئِي هَذَا ثُمَّ صَلَّى رَكْعَتَيْنِ لاَ يُحَدِّثُ فِيهِمَا نَفْسَهُ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{539}\hadithtrans{Humran, the freed slave of 'Uthman said:I saw Uthman call for a vessel (of water) and poured water over his hands three times and then washed them. Then he put his right hand in the vessel and rinsed his mouth and cleaned his nose. Then he washed his face three times and his hands up to the elbow three times; then wiped his head, then washed his feet three times. Then he said that the Messenger of Allah (ﷺ) had said: He who performed ablution like this ablution of mine and offered two raka`ahs of prayer without allowing his thoughts to be distracted, all his previous sins would be expiated}}
\hadithdefcmd{muslim}{540}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ مُحَمَّدِ بْنِ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، وَهُوَ بِفِنَاءِ الْمَسْجِدِ فَجَاءَهُ الْمُؤَذِّنُ عِنْدَ الْعَصْرِ فَدَعَا بِوَضُوءٍ فَتَوَضَّأَ ثُمَّ قَالَ وَاللَّهِ لأُحَدِّثَنَّكُمْ حَدِيثًا لَوْلاَ آيَةٌ فِي كِتَابِ اللَّهِ مَا حَدَّثْتُكُمْ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَتَوَضَّأُ رَجُلٌ مُسْلِمٌ فَيُحْسِنُ الْوُضُوءَ فَيُصَلِّي صَلاَةً إِلاَّ غَفَرَ اللَّهُ لَهُ مَا بَيْنَهُ وَبَيْنَ الصَّلاَةِ الَّتِي تَلِيهَا ‏"‏ ‏.‏\hadithno{540}\hadithtrans{Humran. the freed slave of 'Uthman. said:I heard from 'Uthman b. 'Affan and he was in the courtyard of the mosque, when the Mu'adhdhin (announcer of the prayer) came to him at the time of afternoon prayer. So the ('Uthman) called for the ablution water and performed ablution and then said: By Allah, I am narrating to you a hadith. If there were not a verse in the Book of Allah, I would have never narrated it to you. I heard Allah's Messenger (ﷺ) say: If a Muslim performs ablution and does it well and offers prayer, all his (sins) daring the period from one prayer to another would be pardoned by Allah}}
\hadithdefcmd{muslim}{541}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، جَمِيعًا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ أَبِي أُسَامَةَ ‏ "‏ فَيُحْسِنُ وُضُوءَهُ ثُمَّ يُصَلِّي الْمَكْتُوبَةَ ‏"‏ ‏.‏\hadithno{541}\hadithtrans{This hadith is also narrated on the authority with the same chain of transmitters and in the hadith of Abu Usama the words are:" He who performed the ablution well and then offered the obligatory prayer}}
\hadithdefcmd{muslim}{542}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ ابْنُ شِهَابٍ وَلَكِنْ عُرْوَةُ يُحَدِّثُ عَنْ حُمْرَانَ، أَنَّهُ قَالَ فَلَمَّا تَوَضَّأَ عُثْمَانُ قَالَ وَاللَّهِ لأُحَدِّثَنَّكُمْ حَدِيثًا وَاللَّهِ لَوْلاَ آيَةٌ فِي كِتَابِ اللَّهِ مَا حَدَّثْتُكُمُوهُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَتَوَضَّأُ رَجُلٌ فَيُحْسِنُ وُضُوءَهُ ثُمَّ يُصَلِّي الصَّلاَةَ إِلاَّ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الصَّلاَةِ الَّتِي تَلِيهَا ‏"‏ ‏.‏ قَالَ عُرْوَةُ الآيَةُ ‏\{‏ إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلْنَا مِنَ الْبَيِّنَاتِ وَالْهُدَى‏\}‏ إِلَى قَوْلِهِ ‏\{‏ اللاَّعِنُونَ‏\}‏\hadithno{542}\hadithtrans{Humran reported when 'Uthman performed ablution he said:By Allah, I am narrating to you a hadith had there not been this verse in the Book of Allah. I would not have narrated it to you. Verily I heard the Messenger of Allah (ﷺ) say: Not a person is there who performed ablution, and did it well, then offered prayer, but his sins (which he committed) were not pardoned between the prayer that he offered and the next one. 'Urwa said: The verse is this:" Those who suppress the clear proofs and the guidance which We have sent down"... to His words:" the Cursers" (ii)}}
\hadithdefcmd{muslim}{543}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَحَجَّاجُ بْنُ الشَّاعِرِ، كِلاَهُمَا عَنْ أَبِي الْوَلِيدِ، قَالَ عَبْدٌ حَدَّثَنِي أَبُو الْوَلِيدِ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، قَالَ كُنْتُ عِنْدَ عُثْمَانَ فَدَعَا بِطَهُورٍ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنِ امْرِئٍ مُسْلِمٍ تَحْضُرُهُ صَلاَةٌ مَكْتُوبَةٌ فَيُحْسِنُ وُضُوءَهَا وَخُشُوعَهَا وَرُكُوعَهَا إِلاَّ كَانَتْ كَفَّارَةً لِمَا قَبْلَهَا مِنَ الذُّنُوبِ مَا لَمْ يُؤْتِ كَبِيرَةً وَذَلِكَ الدَّهْرَ كُلَّهُ ‏"‏ ‏.‏\hadithno{543}\hadithtrans{Amr b Sa'id b al-As reported:I was with Uthman, and he called for ablution water and said: I heard Allah's Messenger (ﷺ) say: When the time for a prescribed prayer comes, if any Muslim performs ablution well and offers his prayer with humility and bowing, it will be an expiation for his past sins, so long as he has not committed a major sin; and this applies for all times}}
\hadithdefcmd{muslim}{544}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ الدَّرَاوَرْدِيُّ - عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ قَالَ أَتَيْتُ عُثْمَانَ بْنَ عَفَّانَ بِوَضُوءٍ فَتَوَضَّأَ ثُمَّ قَالَ إِنَّ نَاسًا يَتَحَدَّثُونَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَادِيثَ لاَ أَدْرِي مَا هِيَ إِلاَّ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ مِثْلَ وُضُوئِي هَذَا ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ هَكَذَا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَكَانَتْ صَلاَتُهُ وَمَشْيُهُ إِلَى الْمَسْجِدِ نَافِلَةً ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ عَبْدَةَ أَتَيْتُ عُثْمَانَ فَتَوَضَّأَ ‏.‏\hadithno{544}\hadithtrans{Humran, the freed slave of 'Uthman reported:I brought for Uthman b. 'Affan the ablution water. He performed ablution and then said: Verily the people narrate from the Messenger of Allah (ﷺ) a hadith. I do not know what these are. but (I know this fact) that I saw the Messenger of Allah (ﷺ) perform ablution like this ablution of mine and then he said: He who performed ablution like this, all his previous sins would be expiated and his prayer and going towards the mosque would have an extra reward. In the tradition narrated by Ibn 'Abda (the words are):" I came to Uthman and he performed ablution}}
\hadithdefcmd{muslim}{545}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِقُتَيْبَةَ وَأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي أَنَسٍ، أَنَّ عُثْمَانَ، تَوَضَّأَ بِالْمَقَاعِدِ فَقَالَ أَلاَ أُرِيكُمْ وُضُوءَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ تَوَضَّأَ ثَلاَثًا ثَلاَثًا ‏.‏ وَزَادَ قُتَيْبَةُ فِي رِوَايَتِهِ قَالَ سُفْيَانُ قَالَ أَبُو النَّضْرِ عَنْ أَبِي أَنَسٍ قَالَ وَعِنْدَهُ رِجَالٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{545}\hadithtrans{Abu Anas reported that Uthman performed ablution at Maqi'aid and said:Should I not show you the ablution performed by Allah's Messenger (ﷺ)? And he then washed (the different parts of the body) three times. 4" Qutaiba has added in his narration the words:" There were with him (with Uthman) Companions of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{546}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ وَكِيعٍ، قَالَ أَبُو كُرَيْبٍ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ جَامِعِ بْنِ شَدَّادٍ أَبِي صَخْرَةَ، قَالَ سَمِعْتُ حُمْرَانَ بْنَ أَبَانَ، قَالَ كُنْتُ أَضَعُ لِعُثْمَانَ طَهُورَهُ فَمَا أَتَى عَلَيْهِ يَوْمٌ إِلاَّ وَهُوَ يُفِيضُ عَلَيْهِ نُطْفَةً ‏.‏ وَقَالَ عُثْمَانُ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ انْصِرَافِنَا مِنْ صَلاَتِنَا هَذِهِ - قَالَ مِسْعَرٌ أُرَاهَا الْعَصْرَ - فَقَالَ ‏"‏ مَا أَدْرِي أُحَدِّثُكُمْ بِشَىْءٍ أَوْ أَسْكُتُ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنْ كَانَ خَيْرًا فَحَدِّثْنَا وَإِنْ كَانَ غَيْرَ ذَلِكَ فَاللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ مَا مِنْ مُسْلِمٍ يَتَطَهَّرُ فَيُتِمُّ الطُّهُورَ الَّذِي كَتَبَ اللَّهُ عَلَيْهِ فَيُصَلِّي هَذِهِ الصَّلَوَاتِ الْخَمْسَ إِلاَّ كَانَتْ كَفَّارَاتٍ لِمَا بَيْنَهَا ‏"‏ ‏.‏\hadithno{546}\hadithtrans{Humran b. Aban reported:I used to fetch water for 'Uthman for his purification. Never was there a day that he did not take a bath with a small quantity of water. And Uthman said: The Messenger of Allah (ﷺ) at the time of our returning from our prayer told us (certain things pertaining to purification). Mis'ar said: I find that it was afternoon prayer. He said: I do not know whether I should tell you a thing or keep quiet. We said: Messenger of Allah, tell us if it is good and if it is otherwise, Allah and His Apostle know better. Upon this he said: A Muslim who purifies (himself) and completes purification as enjoined upon him by Allah and then offers the prayers, that will be expiation (of his sins he committed) between these (prayers)}}
\hadithdefcmd{muslim}{547}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ جَامِعِ بْنِ شَدَّادٍ، قَالَ سَمِعْتُ حُمْرَانَ بْنَ أَبَانَ، يُحَدِّثُ أَبَا بُرْدَةَ فِي هَذَا الْمَسْجِدِ فِي إِمَارَةِ بِشْرٍ أَنَّ عُثْمَانَ بْنَ عَفَّانَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَتَمَّ الْوُضُوءَ كَمَا أَمَرَهُ اللَّهُ تَعَالَى فَالصَّلوَاتُ الْمَكْتُوبَاتُ كَفَّارَاتٌ لِمَا بَيْنَهُنَّ ‏"‏ ‏.‏ هَذَا حَدِيثُ ابْنِ مُعَاذٍ وَلَيْسَ فِي حَدِيثِ غُنْدَرٍ فِي إِمَارَةِ بِشْرٍ وَلاَ ذِكْرُ الْمَكْتُوبَاتِ ‏.‏\hadithno{547}\hadithtrans{Jami' b. Shaddad reported:I heard Humran b. Aban narrate to Abu Burda in this very mosque during the governorship of Bishr that 'Uthman b. Alfan said: The Messenger of Allah (ﷺ) observed: He who completed ablution as Allah, the Exalted, enjoined upon him, his obligatory prayers would be explatious (for his minor sins that he would commit) during (the interval) between them. This hadith is transmitted by Ibn Mu'adh, and in the hadith narrated by Ghundar, the words" during the governorship of Bishr" are omitted and there is no mention of the obligatory prayers}}
\hadithdefcmd{muslim}{548}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ وَأَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ قَالَ تَوَضَّأَ عُثْمَانُ بْنُ عَفَّانَ يَوْمًا وُضُوءًا حَسَنًا ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ ‏ "‏ مَنْ تَوَضَّأَ هَكَذَا ثُمَّ خَرَجَ إِلَى الْمَسْجِدِ لاَ يَنْهَزُهُ إِلاَّ الصَّلاَةُ غُفِرَ لَهُ مَا خَلاَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{548}\hadithtrans{Humran, the freed slave of Uthman reported:One day Uthman b. Affan performed the ablution well, and then said: I saw Allah's Messenger (ﷺ) perform ablution, the best ablution, and then observed: He who performed ablution like this and then went towards the mosque and nothing (but the love of) prayer urged him (to do so), all his previous (minor) sins would be expiated}}
\hadithdefcmd{muslim}{549}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ الْحُكَيْمَ بْنَ عَبْدِ اللَّهِ الْقُرَشِيَّ، حَدَّثَهُ أَنَّ نَافِعَ بْنَ جُبَيْرٍ وَعَبْدَ اللَّهِ بْنَ أَبِي سَلَمَةَ حَدَّثَاهُ أَنَّ مُعَاذَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُمَا عَنْ حُمْرَانَ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَوَضَّأَ لِلصَّلاَةِ فَأَسْبَغَ الْوُضُوءَ ثُمَّ مَشَى إِلَى الصَّلاَةِ الْمَكْتُوبَةِ فَصَلاَّهَا مَعَ النَّاسِ أَوْ مَعَ الْجَمَاعَةِ أَوْ فِي الْمَسْجِدِ غَفَرَ اللَّهُ لَهُ ذُنُوبَهُ ‏"‏ ‏.‏\hadithno{549}\hadithtrans{Humran, the freed slave of 'Uthman b. 'Affan, reported on the authority of 'Uthman b. 'Affan that he heard Allah's Messenger (ﷺ) say:He who performed ablution for prayer and performed it properly and then went (to observe) obligatory prayer and offered it along with people or with the congregation or in the mosque, Allah would pardon his sins}}
\hadithdefcmd{muslim}{550}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، - أَخْبَرَنِي الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، مَوْلَى الْحُرَقَةِ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّلاَةُ الْخَمْسُ وَالْجُمُعَةُ إِلَى الْجُمُعَةِ كَفَّارَةٌ لِمَا بَيْنَهُنَّ مَا لَمْ تُغْشَ الْكَبَائِرُ ‏"‏ ‏.‏\hadithno{550}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Five prayers and from one Friday prayer to (the next) Friday prayer is an expiation (of the sins committed in between their intervals) if major sins are not committed}}
\hadithdefcmd{muslim}{551}{حَدَّثَنِي نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَخْبَرَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّلَوَاتُ الْخَمْسُ وَالْجُمُعَةُ إِلَى الْجُمُعَةِ كَفَّارَاتٌ لِمَا بَيْنَهُنَّ ‏"‏ ‏.‏\hadithno{551}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:The five (daily) prayers and one Friday prayer to (the next) Friday prayer are expiations (for the sins committed in the intervals) between them}}
\hadithdefcmd{muslim}{552}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ أَبِي صَخْرٍ، أَنَّ عُمَرَ بْنَ إِسْحَاقَ، مَوْلَى زَائِدَةَ حَدَّثَهُ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ الصَّلَوَاتُ الْخَمْسُ وَالْجُمُعَةُ إِلَى الْجُمُعَةِ وَرَمَضَانُ إِلَى رَمَضَانَ مُكَفِّرَاتٌ مَا بَيْنَهُنَّ إِذَا اجْتَنَبَ الْكَبَائِرَ ‏"‏ ‏.‏\hadithno{552}\hadithtrans{Abu Huraira reported:Verily the Messenger of Allah (ﷺ) said: The five (daily) prayers and from one Friday prayer to the (next) Friday prayer, and from Ramadhan to Ramadhan are expiations for the (sins) committed in between (their intervals) provided one shuns the major sins}}
\hadithdefcmd{muslim}{553}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ رَبِيعَةَ، - يَعْنِي ابْنَ يَزِيدَ - عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، ح وَحَدَّثَنِي أَبُو عُثْمَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ كَانَتْ عَلَيْنَا رِعَايَةُ الإِبِلِ فَجَاءَتْ نَوْبَتِي فَرَوَّحْتُهَا بِعَشِيٍّ فَأَدْرَكْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا يُحَدِّثُ النَّاسَ فَأَدْرَكْتُ مِنْ قَوْلِهِ ‏"‏ مَا مِنْ مُسْلِمٍ يَتَوَضَّأُ فَيُحْسِنُ وُضُوءَهُ ثُمَّ يَقُومُ فَيُصَلِّي رَكْعَتَيْنِ مُقْبِلٌ عَلَيْهِمَا بِقَلْبِهِ وَوَجْهِهِ إِلاَّ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ فَقُلْتُ مَا أَجْوَدَ هَذِهِ ‏.‏ فَإِذَا قَائِلٌ بَيْنَ يَدَىَّ يَقُولُ الَّتِي قَبْلَهَا أَجْوَدُ ‏.‏ فَنَظَرْتُ فَإِذَا عُمَرُ قَالَ إِنِّي قَدْ رَأَيْتُكَ جِئْتَ آنِفًا قَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ يَتَوَضَّأُ فَيُبْلِغُ - أَوْ فَيُسْبِغُ - الْوُضُوءَ ثُمَّ يَقُولُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُ اللَّهِ وَرَسُولُهُ إِلاَّ فُتِحَتْ لَهُ أَبْوَابُ الْجَنَّةِ الثَّمَانِيَةُ يَدْخُلُ مِنْ أَيِّهَا شَاءَ ‏"‏ ‏.‏\hadithno{553}\hadithtrans{Uqba b. 'Amir reported:We were entrusted with the task of tending the camels. On my turn when I came back in the evening after grazing them in the pastures, I found Allah's Messenger (ﷺ) stand and address the people. I heard these words of his: If any Muslim performs ablution well, then stands and prays two rak'ahs setting about them with his heart as well as his face, Paradise would be guaranteed to him. I said: What a fine thing is this! And a narrator who was before me said: The first was better than even this. When I cast a glance, I saw that it was 'Umar who said: I see that you have just come and observed: If anyone amongst you performs the ablution, and then completes the ablution well and then says: I testify that there is no god but Allah and that Muhammad is the servant of Allah and His Messenger, the eight gates of Paradise would be opened for him and he may enter by whichever of them he wishes}}
\hadithdefcmd{muslim}{554}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، وَأَبِي، عُثْمَانَ عَنْ جُبَيْرِ بْنِ نُفَيْرِ بْنِ مَالِكٍ الْحَضْرَمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَذَكَرَ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{554}\hadithtrans{Uqba b. 'Amir al-Juhani reported:Verily the Messenger of Allah (ﷺ) said and then narrated (the hadith) like one (mentioned above) except (this) that he said: He who performed ablution and said: I testify that there is no god but Allah, the One, there is no associate with Him and I testify that Muhammad is His servant and His Messenger}}
\hadithdefcmd{muslim}{555}{حَدَّثَنِي مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَمْرِو بْنِ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدِ بْنِ عَاصِمٍ الأَنْصَارِيِّ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قِيلَ لَهُ تَوَضَّأْ لَنَا وُضُوءَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَدَعَا بِإِنَاءٍ فَأَكْفَأَ مِنْهَا عَلَى يَدَيْهِ فَغَسَلَهُمَا ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ فَاسْتَخْرَجَهَا فَمَضْمَضَ وَاسْتَنْشَقَ مِنْ كَفٍّ وَاحِدَةٍ فَفَعَلَ ذَلِكَ ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ فَاسْتَخْرَجَهَا فَغَسَلَ وَجْهَهُ ثَلاَثًا ثُمَّ أَدْخَلَ يَدَهُ فَاسْتَخْرَجَهَا فَغَسَلَ يَدَيْهِ إِلَى الْمِرْفَقَيْنِ مَرَّتَيْنِ مَرَّتَيْنِ ثُمَّ أَدْخَلَ يَدَهُ فَاسْتَخْرَجَهَا فَمَسَحَ بِرَأْسِهِ فَأَقْبَلَ بِيَدَيْهِ وَأَدْبَرَ ثُمَّ غَسَلَ رِجْلَيْهِ إِلَى الْكَعْبَيْنِ ثُمَّ قَالَ هَكَذَا كَانَ وُضُوءُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{555}\hadithtrans{Abdullah b. Zaid b. 'Asim al-Ansari, who was a Companion (of the Holy Prophet), reported:It was said to him (by people): Perform for us the ablution (as it was performed) by the Messenger of Allah (way peace be upon him). He ('Abdullah b. Zaid) called for a vessel (of water), and poured water from it on his hands and washed them three times. Then he inserted his hand (in the vessel) and brought it (water) out, rinsed his mouth and snuffed up water from the palm of one hand doing that three times, He again inserted his hand and brought it out and washed his face three times, then inserted his hand and brought it out and washed each arm up to the elbow twice, then inserted his hand and brought it out and wiped his head both front and back with his hands. He then washed his feet up to the ankles, and then said: This is how God's Messenger (peace be upon him) performed ablution}}
\hadithdefcmd{muslim}{556}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ، - هُوَ ابْنُ بِلاَلٍ - عَنْ عَمْرِو بْنِ يَحْيَى، بِهَذَا الإِسْنَادِ نَحْوَهُ وَلَمْ يَذْكُرِ الْكَعْبَيْنِ ‏.‏\hadithno{556}\hadithtrans{This hadith is narrated by Amr b. Yahya with the same chain of transmitters, but there is no mention of ankles}}
\hadithdefcmd{muslim}{557}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَمْرِو بْنِ يَحْيَى، بِهَذَا الإِسْنَادِ وَقَالَ مَضْمَضَ وَاسْتَنْثَرَ ثَلاَثًا ‏.‏ وَلَمْ يَقُلْ مِنْ كَفٍّ وَاحِدَةٍ ‏.‏ وَزَادَ بَعْدَ قَوْلِهِ فَأَقْبَلَ بِهِمَا وَأَدْبَرَ بَدَأَ بِمُقَدَّمِ رَأْسِهِ ثُمَّ ذَهَبَ بِهِمَا إِلَى قَفَاهُ ثُمَّ رَدَّهُمَا حَتَّى رَجَعَ إِلَى الْمَكَانِ الَّذِي بَدَأَ مِنْهُ وَغَسَلَ رِجْلَيْهِ ‏.‏\hadithno{557}\hadithtrans{Malik b. Anas narrated it from 'Amr b. Yahya with the same chain of transmitters, transmitters and mentioned the rinsing (of mouth) and snuffing (of water into the nostrils) three times, but he did not mention" from one palm," and made this addition:He moved them (his hands) for wiping to the front of his head and then the nape of his neck, then bringing them back till he reached the place from which he had begun, after which he washed his feet}}
\hadithdefcmd{muslim}{558}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، بِمِثْلِ إِسْنَادِهِمْ وَاقْتَصَّ الْحَدِيثَ وَقَالَ فِيهِ فَمَضْمَضَ وَاسْتَنْشَقَ وَاسْتَنْثَرَ مِنْ ثَلاَثِ غَرَفَاتٍ ‏.‏ وَقَالَ أَيْضًا فَمَسَحَ بِرَأْسِهِ فَأَقْبَلَ بِهِ وَأَدْبَرَ مَرَّةً وَاحِدَةً ‏.‏ قَالَ بَهْزٌ أَمْلَى عَلَىَّ وُهَيْبٌ هَذَا الْحَدِيثَ ‏.‏ وَقَالَ وُهَيْبٌ أَمْلَى عَلَىَّ عَمْرُو بْنُ يَحْيَى هَذَا الْحَدِيثَ مَرَّتَيْنِ ‏.‏\hadithno{558}\hadithtrans{Babz reported:This hadith has been narrated by Wuwb on the authority of 'Amr b. Yahyi with the same chain of transmitters and it has been mentioned therein: He rinsed his mouth. snuffed up water in nostrils and cleaned the nose with three handfuls and wiped his head moving (his hand) in front and then back once. Bahz said: Wuhaib narrated this hadith to me and Wuhaib said: Amr b. Yahya narrated to me this hadith twice}}
\hadithdefcmd{muslim}{559}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَبُو الطَّاهِرِ، قَالُوا حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ حَبَّانَ بْنَ وَاسِعٍ، حَدَّثَهُ أَنَّ أَبَاهُ حَدَّثَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيَّ، يَذْكُرُ أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم تَوَضَّأَ فَمَضْمَضَ ثُمَّ اسْتَنْثَرَ ثُمَّ غَسَلَ وَجْهَهُ ثَلاَثًا وَيَدَهُ الْيُمْنَى ثَلاَثًا وَالأُخْرَى ثَلاَثًا وَمَسَحَ بِرَأْسِهِ بِمَاءٍ غَيْرِ فَضْلِ يَدِهِ وَغَسَلَ رِجْلَيْهِ حَتَّى أَنْقَاهُمَا ‏.‏ قَالَ أَبُو الطَّاهِرِ حَدَّثَنَا ابْنُ وَهْبٍ عَنْ عَمْرِو بْنِ الْحَارِثِ ‏.‏\hadithno{559}\hadithtrans{Abdullah b. Zaid b. 'Asim al-Mazini reported:He saw Allah's Messenger (ﷺ) perform the ablution. He rinsed his mouth then cleaned his nose, then washed his face three times, then washed his right hand thrice and then the other one, thrice. He then took fresh water and wiped his head and then washed his feet till he cleaned them}}
\hadithdefcmd{muslim}{560}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَمْرٌو النَّاقِدُ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ قُتَيْبَةُ حَدَّثَنَا سُفْيَانُ، - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَجْمَرَ أَحَدُكُمْ فَلْيَسْتَجْمِرْ وِتْرًا وَإِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَجْعَلْ فِي أَنْفِهِ مَاءً ثُمَّ لْيَنْتَثِرْ ‏"‏ ‏.‏\hadithno{560}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:When anyone wipes himself with pebbles (after answering the call of nature) he must make use of an odd number and when any one of you performs ablution he must snuff in his nose water and then clean it}}
\hadithdefcmd{muslim}{561}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَسْتَنْشِقْ بِمَنْخِرَيْهِ مِنَ الْمَاءِ ثُمَّ لْيَنْتَثِرْ ‏"‏ ‏.‏\hadithno{561}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira transmitted to us from Muhammad, the Messenger of Allah (ﷺ), and he mentioned a number of a hadith, of which this is one: that the Messenger of Allah (ﷺ) said: When anyone amongst you (performs ablution) he must snuff his nostrils with water and then clean them}}
\hadithdefcmd{muslim}{562}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَوَضَّأَ فَلْيَسْتَنْثِرْ وَمَنِ اسْتَجْمَرَ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{562}\hadithtrans{Abu Huraira reported:The Messenger of Allah (way peace he upon him) said: When anyone performs ablution he must clean his nose and when anyone wipes himself with pebbles (after answering the call of nature) he must do that odd number of times}}
\hadithdefcmd{muslim}{563}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا حَسَّانُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، وَأَبَا، سَعِيدٍ الْخُدْرِيَّ يَقُولاَنِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{563}\hadithtrans{It has been transmitted by Abu Huraira and Abu Sa'id al-Khudri (both of them the reputed Companions of the Holy Prophet) that the Messenger of Allah (ﷺ) said like that}}
\hadithdefcmd{muslim}{564}{حَدَّثَنِي بِشْرُ بْنُ الْحَكَمِ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ مَنَامِهِ فَلْيَسْتَنْثِرْ ثَلاَثَ مَرَّاتٍ فَإِنَّ الشَّيْطَانَ يَبِيتُ عَلَى خَيَاشِيمِهِ ‏"‏ ‏.‏\hadithno{564}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said. When any one of you awakes up from sleep and performs ablution, he must clean his nose three times, for the devil spends the night in the interior of his nose}}
\hadithdefcmd{muslim}{565}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَجْمَرَ أَحَدُكُمْ فَلْيُوتِرْ ‏"‏ ‏.‏\hadithno{565}\hadithtrans{Jabir b. 'Abdullah reported that he heard the Messenger of Allah (ﷺ) say:When anyone wipes himself with pebbles (after answering the call of nature) he should do this odd number of times}}
\hadithdefcmd{muslim}{566}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَبُو الطَّاهِرِ، وَأَحْمَدُ بْنُ عِيسَى، قَالُوا أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مَخْرَمَةَ بْنِ بُكَيْرٍ، عَنْ أَبِيهِ، عَنْ سَالِمٍ، مَوْلَى شَدَّادٍ قَالَ دَخَلْتُ عَلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم يَوْمَ تُوُفِّيَ سَعْدُ بْنُ أَبِي وَقَّاصٍ فَدَخَلَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ فَتَوَضَّأَ عِنْدَهَا فَقَالَتْ يَا عَبْدَ الرَّحْمَنِ أَسْبِغِ الْوُضُوءَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{566}\hadithtrans{Salim, the freed slave of Shaddad, said:I came to 'A'isha, the wife of the Prophet (ﷺ), on the day when Sa'db. Abi Waqqas died. 'Abd al-Rahman b. Abu Bakr also came there and he performed ablution in her presence. She (Hadrat 'A'isha) said: Abd al-Rahman, complete the ablution as I heard the Allah's Messenger (ﷺ) say: Woe to the heels because of hell-fire}}
\hadithdefcmd{muslim}{567}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ، أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا عَبْدِ اللَّهِ، مَوْلَى شَدَّادِ بْنِ الْهَادِ حَدَّثَهُ أَنَّهُ، دَخَلَ عَلَى عَائِشَةَ فَذَكَرَ عَنْهَا عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{567}\hadithtrans{Abdullah, the freed slave of Shahddad, came to 'A'isha and transmitted from her a hadith like this (which she narrated) from the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{568}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَأَبُو مَعْنٍ الرَّقَاشِيُّ قَالاَ حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي - أَوْ، حَدَّثَنَا - أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي سَالِمٌ، مَوْلَى الْمَهْرِيِّ قَالَ خَرَجْتُ أَنَا وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ، فِي جَنَازَةِ سَعْدِ بْنِ أَبِي وَقَّاصٍ فَمَرَرْنَا عَلَى بَابِ حُجْرَةِ عَائِشَةَ فَذَكَرَ عَنْهَا عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{568}\hadithtrans{Salim, the freed slave of Mahri, reported:I and 'Abd al-Rahman b. Abu Bakr went out (in order to join) the funeral procession of Sa'd b. Abi Waqqas and passed by the door of the residence of 'A'isha, and then he transmitted a hadith like this from her who (narrated it) from the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{569}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنِي نُعَيْمُ بْنُ عَبْدِ اللَّهِ، عَنْ سَالِمٍ، مَوْلَى شَدَّادِ بْنِ الْهَادِ قَالَ كُنْتُ أَنَا مَعَ، عَائِشَةَ - رضى الله عنها - فَذَكَرَ عَنْهَا عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{569}\hadithtrans{Salim, the freed slave of Shaddad b. al-Had said:I was in the presence of 'A'isha, and then narrated on her authority a hadith like this from the Prophet (way peace be upon him)}}
\hadithdefcmd{muslim}{570}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَجَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ مَكَّةَ إِلَى الْمَدِينَةِ حَتَّى إِذَا كُنَّا بِمَاءٍ بِالطَّرِيقِ تَعَجَّلَ قَوْمٌ عِنْدَ الْعَصْرِ فَتَوَضَّئُوا وَهُمْ عِجَالٌ فَانْتَهَيْنَا إِلَيْهِمْ وَأَعْقَابُهُمْ تَلُوحُ لَمْ يَمَسَّهَا الْمَاءُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏\hadithno{570}\hadithtrans{Abdullah b. 'Amr reported:We returned from Mecca to Medina with the Messenger of Allah (ﷺ), and when we came to some water on the way, some of the people were in a hurry at the time of the afternoon prayer and performed ablution hurriedly; and when we reached them, their heels were dry, no water had touched them. The Prophet (ﷺ) said: Woe to (dry) heels, because of Hell-fire. Make your ablution thorough}}
\hadithdefcmd{muslim}{571}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِ شُعْبَةَ ‏ "‏ أَسْبِغُوا الْوُضُوءَ ‏"‏ ‏.‏ وَفِي حَدِيثِهِ عَنْ أَبِي يَحْيَى الأَعْرَجِ ‏.‏\hadithno{571}\hadithtrans{In the hadith transmitted by Shu'ba these words are not there:" Complete the Wudu," and there is the name of Abu Yahya al-A'raj (a narrator)}}
\hadithdefcmd{muslim}{572}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ جَمِيعًا عَنْ أَبِي عَوَانَةَ، - قَالَ أَبُو كَامِلٍ حَدَّثَنَا أَبُو عَوَانَةَ، - عَنْ أَبِي بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ تَخَلَّفَ عَنَّا النَّبِيُّ صلى الله عليه وسلم فِي سَفَرٍ سَافَرْنَاهُ فَأَدْرَكَنَا وَقَدْ حَضَرَتْ صَلاَةُ الْعَصْرِ فَجَعَلْنَا نَمْسَحُ عَلَى أَرْجُلِنَا فَنَادَى ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{572}\hadithtrans{Abdullah b. Amr reported:The Messenger of Allah (ﷺ) lagged behind us on a journey. We travelled (back) and be took him; and then came the time of the afternoon prayer, and as we were going to wipe our feet he (the Holy Prophet) called out: Woe to the heels because of Hell-fire}}
\hadithdefcmd{muslim}{573}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ زِيَادٍ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً لَمْ يَغْسِلْ عَقِبَيْهِ فَقَالَ ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{573}\hadithtrans{Abu Huraira reported:Allah's Apostle (ﷺ) saw a man who did not wash his heel and he remarked: Woe to the heels because of hell-fire}}
\hadithdefcmd{muslim}{574}{حَدَّثَنَا قُتَيْبَةُ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ رَأَى قَوْمًا يَتَوَضَّئُونَ مِنَ الْمِطْهَرَةِ فَقَالَ أَسْبِغُوا الْوُضُوءَ فَإِنِّي سَمِعْتُ أَبَا الْقَاسِمِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَيْلٌ لِلْعَرَاقِيبِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{574}\hadithtrans{Abu Huraira reported:He saw people perform ablution with the help of a water jar and he said: Complete the Wudu for i heard Abu al-Qasim (ﷺ) say: Woe to the hamstrings because of hell-fire}}
\hadithdefcmd{muslim}{575}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَيْلٌ لِلأَعْقَابِ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{575}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Woe to the heels because of hell-fire}}
\hadithdefcmd{muslim}{576}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَخْبَرَنِي عُمَرُ بْنُ الْخَطَّابِ، أَنَّ رَجُلاً، تَوَضَّأَ فَتَرَكَ مَوْضِعَ ظُفُرٍ عَلَى قَدَمِهِ فَأَبْصَرَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ ارْجِعْ فَأَحْسِنْ وُضُوءَكَ ‏"‏ ‏.‏ فَرَجَعَ ثُمَّ صَلَّى ‏.‏\hadithno{576}\hadithtrans{Jabir reported:'Umar b. Khattab said that a person performed ablution and left a small part equal to the space of a nail (unwashed). The Apostle of Allah (ﷺ) saw that and said: Go back and perform ablution well. He then went back (performed ablution well) and offered the prayer}}
\hadithdefcmd{muslim}{577}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، ح وَحَدَّثَنَا أَبُو الطَّاهِرِ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ الْعَبْدُ الْمُسْلِمُ - أَوِ الْمُؤْمِنُ - فَغَسَلَ وَجْهَهُ خَرَجَ مِنْ وَجْهِهِ كُلُّ خَطِيئَةٍ نَظَرَ إِلَيْهَا بِعَيْنَيْهِ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ - فَإِذَا غَسَلَ يَدَيْهِ خَرَجَ مِنْ يَدَيْهِ كُلُّ خَطِيئَةٍ كَانَ بَطَشَتْهَا يَدَاهُ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ - فَإِذَا غَسَلَ رِجْلَيْهِ خَرَجَتْ كُلُّ خَطِيئَةٍ مَشَتْهَا رِجْلاَهُ مَعَ الْمَاءِ - أَوْ مَعَ آخِرِ قَطْرِ الْمَاءِ - حَتَّى يَخْرُجَ نَقِيًّا مِنَ الذُّنُوبِ ‏"‏ ‏.‏\hadithno{577}\hadithtrans{Abu Huraira reported:Allah's Messenger (ﷺ) said: When a bondsman-a Muslim or a believer-washes his face (in course of ablution), every sin he contemplated with his eyes, will be washed away from his face along with water, or with the last drop of water; when he washes his hands, every sin they wrought will be effaced from his hands with the water, or with the last drop of water; and when he washes his feet, every sin towards which his feet have walked will be washed away with the water or with the last drop of water with the result that he comes out pure from all sins}}
\hadithdefcmd{muslim}{578}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرِ بْنِ رِبْعِيٍّ الْقَيْسِيُّ، حَدَّثَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، عَنْ عَبْدِ الْوَاحِدِ، - وَهُوَ ابْنُ زِيَادٍ - حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ حُمْرَانَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ خَرَجَتْ خَطَايَاهُ مِنْ جَسَدِهِ حَتَّى تَخْرُجَ مِنْ تَحْتِ أَظْفَارِهِ ‏"‏ ‏.‏\hadithno{578}\hadithtrans{Uthman b. 'Affan reported:The Messenger of Allah (way peace be upon him) said: He who performed ablution well, his sins would come out from his body, even coming out from under his nails}}
\hadithdefcmd{muslim}{579}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَالْقَاسِمُ بْنُ زَكَرِيَّاءَ بْنِ دِينَارٍ وَعَبْدُ بْنُ حُمَيْدٍ قَالُوا حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنِي عُمَارَةُ بْنُ غَزِيَّةَ الأَنْصَارِيُّ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ يَتَوَضَّأُ فَغَسَلَ وَجْهَهُ فَأَسْبَغَ الْوُضُوءَ ثُمَّ غَسَلَ يَدَهُ الْيُمْنَى حَتَّى أَشْرَعَ فِي الْعَضُدِ ثُمَّ يَدَهُ الْيُسْرَى حَتَّى أَشْرَعَ فِي الْعَضُدِ ثُمَّ مَسَحَ رَأْسَهُ ثُمَّ غَسَلَ رِجْلَهُ الْيُمْنَى حَتَّى أَشْرَعَ فِي السَّاقِ ثُمَّ غَسَلَ رِجْلَهُ الْيُسْرَى حَتَّى أَشْرَعَ فِي السَّاقِ ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ ‏.‏ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْتُمُ الْغُرُّ الْمُحَجَّلُونَ يَوْمَ الْقِيَامَةِ مِنْ إِسْبَاغِ الْوُضُوءِ فَمَنِ اسْتَطَاعَ مِنْكُمْ فَلْيُطِلْ غُرَّتَهُ وَتَحْجِيلَهُ ‏"‏ ‏.‏\hadithno{579}\hadithtrans{Nu'aim b. 'Abdullah al-Mujmir reported:I saw Abu Huraira perform ablution. He washed his face and washed it well. He then washed his right hand including a portion of his arm. He then washed his left hand including a portion of his arm. He then wiped his head. He then washed his right foot including his shank, and then washed his left foot including shank, and then said: This is how I saw Allah's Messenger (ﷺ) perform his ablution. And (Abu Huraira) added that the Messenger of Allah (ﷺ) had observed: You shall have your faces hands and feet bright on the Day of Resurrection because of your perfect ablution. He who can afford among you, let him increase the brightness of his forehead and that of hands and legs}}
\hadithdefcmd{muslim}{580}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ رَأَى أَبَا هُرَيْرَةَ يَتَوَضَّأُ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ حَتَّى كَادَ يَبْلُغُ الْمَنْكِبَيْنِ ثُمَّ غَسَلَ رِجْلَيْهِ حَتَّى رَفَعَ إِلَى السَّاقَيْنِ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أُمَّتِي يَأْتُونَ يَوْمَ الْقِيَامَةِ غُرًّا مُحَجَّلِينَ مِنْ أَثَرِ الْوُضُوءِ فَمَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يُطِيلَ غُرَّتَهُ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{580}\hadithtrans{Nu'aim b. 'Abdallah reported:He saw Abu Huraira perform ablution. He washed his face and washed his hands up to the arms. He then washed his feet and reached up to the shanks and then said: I heard Allah's Messenger (ﷺ) say: My people would come with bright faces and bright hands and feet on account of the marks of ablution, so he who can increase the lustre of his forehead (and that of his hands and legs) should do so}}
\hadithdefcmd{muslim}{581}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ مَرْوَانَ الْفَزَارِيِّ، - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا مَرْوَانُ، - عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، سَعْدِ بْنِ طَارِقٍ عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ حَوْضِي أَبْعَدُ مِنْ أَيْلَةَ مِنْ عَدَنٍ لَهُوَ أَشَدُّ بَيَاضًا مِنَ الثَّلْجِ وَأَحْلَى مِنَ الْعَسَلِ بِاللَّبَنِ وَلآنِيَتُهُ أَكْثَرُ مِنْ عَدَدِ النُّجُومِ وَإِنِّي لأَصُدُّ النَّاسَ عَنْهُ كَمَا يَصُدُّ الرَّجُلُ إِبِلَ النَّاسِ عَنْ حَوْضِهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَتَعْرِفُنَا يَوْمَئِذٍ قَالَ ‏"‏ نَعَمْ لَكُمْ سِيمَا لَيْسَتْ لأَحَدٍ مِنَ الأُمَمِ تَرِدُونَ عَلَىَّ غُرًّا مُحَجَّلِينَ مِنْ أَثَرِ الْوُضُوءِ ‏"‏ ‏.‏\hadithno{581}\hadithtrans{Abu Huraira reported:Verily Allah's Messenger (ﷺ) said: My Cistern has its dimensions wider than the distance between Aila and Aden, and its water is whiter than ice and sweeter than the honey diluted with milk, and its cups are more numerous than the numbers of the stars. Verily I shall prevent the (faithless) people therefrom just as a man prevents the camels of the people from his fountain. They said: Messenger of Allah, will you recognise us on that day? He said: Yes, you will have distinctive marks which nobody among the peoples (except you) will have; you would come to me with blazing forehead and bright hands and feet on account of the traces of ablution}}
\hadithdefcmd{muslim}{582}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، - وَاللَّفْظُ لِوَاصِلٍ - قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَرِدُ عَلَىَّ أُمَّتِي الْحَوْضَ وَأَنَا أَذُودُ النَّاسَ عَنْهُ كَمَا يَذُودُ الرَّجُلُ إِبِلَ الرَّجُلِ عَنْ إِبِلِهِ ‏"‏ ‏.‏ قَالُوا يَا نَبِيَّ اللَّهِ أَتَعْرِفُنَا قَالَ ‏"‏ نَعَمْ لَكُمْ سِيمَا لَيْسَتْ لأَحَدٍ غَيْرِكُمْ تَرِدُونَ عَلَىَّ غُرًّا مُحَجَّلِينَ مِنْ آثَارِ الْوُضُوءِ وَلَيُصَدَّنَّ عَنِّي طَائِفَةٌ مِنْكُمْ فَلاَ يَصِلُونَ فَأَقُولُ يَا رَبِّ هَؤُلاَءِ مِنْ أَصْحَابِي فَيُجِيبُنِي مَلَكٌ فَيَقُولُ وَهَلْ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏ ‏.‏\hadithno{582}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) said:My people would come to me on the Cistern and I would drive away persons (from it) just as a person drives away other people's camels from his camels. They (the hearers) said: Apostle of Allah, would you recognize us? He replied: Yea, you would have a mark which other people will not have. You would come to me with a white blaze on your foreheads and white marks on your feet because of the traces of ablution. A group among you would be prevented from coming to me, and they would not meet me, and I would say: O my Lord, they are my companions. Upon this an angel would reply to me saying: Do you know what these people did after you}}
\hadithdefcmd{muslim}{583}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ سَعْدِ بْنِ طَارِقٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ حَوْضِي لأَبْعَدُ مِنْ أَيْلَةَ مِنْ عَدَنٍ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَذُودُ عَنْهُ الرِّجَالَ كَمَا يَذُودُ الرَّجُلُ الإِبِلَ الْغَرِيبَةَ عَنْ حَوْضِهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَتَعْرِفُنَا قَالَ ‏"‏ نَعَمْ تَرِدُونَ عَلَىَّ غُرًّا مُحَجَّلِينَ مِنْ آثَارِ الْوُضُوءِ لَيْسَتْ لأَحَدٍ غَيْرِكُمْ ‏"‏ ‏.‏\hadithno{583}\hadithtrans{Hudhaifa reported:The Messenger of Allah (ﷺ) said: My Cistern is bigger than the space between Aila and Aden. By Him in Whose Hand is my life, I will drive away persons (from it) just as a person drives away unknown camels from his cistern. They (the companions) said: Messenger of Allah, would you recognise us? He said: Yes, you would come to me with white faces, and white hands and feet on account of the traces of ablution. None but you would have (this mark)}}
\hadithdefcmd{muslim}{584}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَسُرَيْجُ بْنُ يُونُسَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى الْمَقْبُرَةَ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ وَدِدْتُ أَنَّا قَدْ رَأَيْنَا إِخْوَانَنَا ‏"‏ ‏.‏ قَالُوا أَوَلَسْنَا إِخْوَانَكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَنْتُمْ أَصْحَابِي وَإِخْوَانُنَا الَّذِينَ لَمْ يَأْتُوا بَعْدُ ‏"‏ ‏.‏ فَقَالُوا كَيْفَ تَعْرِفُ مَنْ لَمْ يَأْتِ بَعْدُ مِنْ أُمَّتِكَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ أَرَأَيْتَ لَوْ أَنَّ رَجُلاً لَهُ خَيْلٌ غُرٌّ مُحَجَّلَةٌ بَيْنَ ظَهْرَىْ خَيْلٍ دُهْمٍ بُهْمٍ أَلاَ يَعْرِفُ خَيْلَهُ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّهُمْ يَأْتُونَ غُرًّا مُحَجَّلِينَ مِنَ الْوُضُوءِ وَأَنَا فَرَطُهُمْ عَلَى الْحَوْضِ أَلاَ لَيُذَادَنَّ رِجَالٌ عَنْ حَوْضِي كَمَا يُذَادُ الْبَعِيرُ الضَّالُّ أُنَادِيهِمْ أَلاَ هَلُمَّ ‏.‏ فَيُقَالُ إِنَّهُمْ قَدْ بَدَّلُوا بَعْدَكَ ‏.‏ فَأَقُولُ سُحْقًا سُحْقًا ‏"‏ ‏.‏\hadithno{584}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) came to the graveyard and said: "Peace be upon you! The abode of the believing people and we, if God so wills, are about to join you. I love to see my brothers." They (the hearers) said: Aren't we your brothers, O Messenger of Allah? He said: You are my companions, and our brothers are those who have, so far, not come into the world. They said: Messenger of Allah, how would you recognise those persons of your Ummah who have not yet been born? He said: Supposing a man had horses with white blazes on foreheads and legs among horses which were all black, tell me, would he not recognise his own horses? They said: Certainly, O Messenger of Allah. He said: They would come with white faces and arms and legs owing to ablution, and I would arrive at the Cistern before them. Some people would be driven away from my Cistern as the stray camel is driven away. I would call out: Come, come. Then it would be said (to me): These people changed themselves after you, and I would say: Be off, be off}}
\hadithdefcmd{muslim}{585}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، جَمِيعًا عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمَقْبُرَةِ فَقَالَ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ إِسْمَاعِيلَ بْنِ جَعْفَرٍ غَيْرَ أَنَّ حَدِيثَ مَالِكٍ ‏"‏ فَلَيُذَادَنَّ رِجَالٌ عَنْ حَوْضِي ‏"‏ ‏.‏\hadithno{585}\hadithtrans{Abu Huraira reported:The Messenger of Allah (may peace The upon him) went out to the graveyard and said: Peace be upon you, the abode of the believing people. and If Allah so wills we shall join you.... (and so on and so forth) like the hadith narrated by Isma'il b. Ja'far except the words of Malik: Then some persons would be driven away from my Cistern}}
\hadithdefcmd{muslim}{586}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا خَلَفٌ، - يَعْنِي ابْنَ خَلِيفَةَ - عَنْ أَبِي مَالِكٍ الأَشْجَعِيَّ، عَنْ أَبِي حَازِمٍ، قَالَ كُنْتُ خَلْفَ أَبِي هُرَيْرَةَ وَهُوَ يَتَوَضَّأُ لِلصَّلاَةِ فَكَانَ يَمُدُّ يَدَهُ حَتَّى تَبْلُغَ إِبْطَهُ فَقُلْتُ لَهُ يَا أَبَا هُرَيْرَةَ مَا هَذَا الْوُضُوءُ فَقَالَ يَا بَنِي فَرُّوخَ أَنْتُمْ هَا هُنَا لَوْ عَلِمْتُ أَنَّكُمْ هَا هُنَا مَا تَوَضَّأْتُ هَذَا الْوُضُوءَ سَمِعْتُ خَلِيلِي صلى الله عليه وسلم يَقُولُ ‏ "‏ تَبْلُغُ الْحِلْيَةُ مِنَ الْمُؤْمِنِ حَيْثُ يَبْلُغُ الْوَضُوءُ ‏"‏ ‏.‏\hadithno{586}\hadithtrans{Abu Hazim reported:I was (standing) behind Abu Huraira and he was performing the ablution for prayer. He extended the (washing) of his hand that it went up to his armpit. I said to him: O Abu Huraira, what is this ablution? He said: O of the tribe of Faruukh, you are here; if I knew that you were here, I would have never performed ablution like this; I have heard my Friend (ﷺ) say. In a believer adornment would reach the places where ablution reaches}}
\hadithdefcmd{muslim}{587}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أَدُلُّكُمْ عَلَى مَا يَمْحُو اللَّهُ بِهِ الْخَطَايَا وَيَرْفَعُ بِهِ الدَّرَجَاتِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِسْبَاغُ الْوُضُوءِ عَلَى الْمَكَارِهِ وَكَثْرَةُ الْخُطَا إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏\hadithno{587}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Should I not suggest to you that by which Allah obliterates the sins and elevates the ranks (of a man). They (the hearers) said: Yes, Messenger of Allah. He said: Performing the ablution thoroughly despite odds, tranverside of more paces towards the mosque, and waiting for the next prayer after observing a prayer, and that is mindfulness}}
\hadithdefcmd{muslim}{588}{حَدَّثَنِي إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، جَمِيعًا عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، بِهَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِ شُعْبَةَ ذِكْرُ الرِّبَاطِ وَفِي حَدِيثِ مَالِكٍ ثِنْتَيْنِ ‏ "‏ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏\hadithno{588}\hadithtrans{This hadith has been narrated on the authority of `Ali b. `Abd al-Rahman with the same chain of transmitters and there is no mention of the word of al-Ribat in the hadith transmitted by Shu`ba and in the hadith narrated by Malik "Ribat" has been mentioned twice. This is the "Ribat" for you, this is the "Ribat" for you}}
\hadithdefcmd{muslim}{589}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى الْمُؤْمِنِينَ - وَفِي حَدِيثِ زُهَيْرٍ عَلَى أُمَّتِي - لأَمَرْتُهُمْ بِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{589}\hadithtrans{Abu Huraira reported:The Apostle (ﷺ) said: Were it not that I might over-burden the believers-and in the hadith transmitted by Zuhair" people" -I would have ordered them to use toothstick at every time of prayer}}
\hadithdefcmd{muslim}{590}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ قُلْتُ بِأَىِّ شَىْءٍ كَانَ يَبْدَأُ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ بَيْتَهُ قَالَتْ بِالسِّوَاكِ ‏.‏\hadithno{590}\hadithtrans{Miqdam b. Shuraih narrated it from his father who said:I asked A'isha what Allah's Apostle (ﷺ) did first when he entered his house, and she replied: He used tooth-stick (first of all)}}
\hadithdefcmd{muslim}{591}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ بَيْتَهُ بَدَأَ بِالسِّوَاكِ ‏.‏\hadithno{591}\hadithtrans{A'isha reported:Whenever Allah's Messenger (ﷺ) entered his house, he used tooth-stick first of all}}
\hadithdefcmd{muslim}{592}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ، - وَهُوَ ابْنُ جَرِيرٍ الْمَعْوَلِيُّ - عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَطَرَفُ السِّوَاكِ عَلَى لِسَانِهِ ‏.‏\hadithno{592}\hadithtrans{Abu Musa reported:I went to the Apostle (ﷺ) and found one end of the tooth-stick upon his tongue (i. e. he was rinsing his mouth)}}
\hadithdefcmd{muslim}{593}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ لِيَتَهَجَّدَ يَشُوصُ فَاهُ بِالسِّوَاكِ ‏.‏\hadithno{593}\hadithtrans{Huddaifa reported:Whenever the Messenger of Allah (ﷺ) got up for Tahajjud prayer, he cleansed his mouth with the tooth-stick}}
\hadithdefcmd{muslim}{594}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، كِلاَهُمَا عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ ‏.‏ بِمِثْلِهِ وَلَمْ يَقُولُوا لِيَتَهَجَّدَ ‏.‏\hadithno{594}\hadithtrans{This hadith is reported from Hudaifa by another chain of transmitters. Whenever he (the Holy Prophet) got up in the night, they (the transmitters) have not mentioned the words:for offering Tahajjud prayer}}
\hadithdefcmd{muslim}{595}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَحُصَيْنٌ، وَالأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ مِنَ اللَّيْلِ يَشُوصُ فَاهُ بِالسِّوَاكِ ‏.‏\hadithno{595}\hadithtrans{Hudaifa reported:Whenever he (the Holy Prophet) got up for prayer during the night, he cleansed his mouth with the tooth-stick}}
\hadithdefcmd{muslim}{596}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو الْمُتَوَكِّلِ، أَنَّ ابْنَ عَبَّاسٍ، حَدَّثَهُ أَنَّهُ، بَاتَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم مِنْ آخِرِ اللَّيْلِ فَخَرَجَ فَنَظَرَ فِي السَّمَاءِ ثُمَّ تَلاَ هَذِهِ الآيَةَ فِي آلِ عِمْرَانَ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ وَاخْتِلاَفِ اللَّيْلِ وَالنَّهَارِ‏\}‏ حَتَّى بَلَغَ ‏\{‏ فَقِنَا عَذَابَ النَّارِ‏\}‏ ثُمَّ رَجَعَ إِلَى الْبَيْتِ فَتَسَوَّكَ وَتَوَضَّأَ ثُمَّ قَامَ فَصَلَّى ثُمَّ اضْطَجَعَ ثُمَّ قَامَ فَخَرَجَ فَنَظَرَ إِلَى السَّمَاءِ فَتَلاَ هَذِهِ الآيَةَ ثُمَّ رَجَعَ فَتَسَوَّكَ فَتَوَضَّأَ ثُمَّ قَامَ فَصَلَّى ‏.‏\hadithno{596}\hadithtrans{Ibn 'Abbas reported that he spent a night at the house of the Messenger of Allah (ﷺ), The Apostle of Allah (way peace be upon him) got up for prayer in the latter part of the night. He went out and looked towards the sky and then recited this verse (190th) of AI-i-'Imran:" Verily in the creation of the heavens and the earth and the alternation of night and day." up to the (words)" save us from the torment of Hell." He then returned to his house, used the tooth-stick, performed the ablution, and then got up and offered the prayer. He than lay down on the bed. and again got up and went out and looked towards the sky and recited this verse (mentioned above), then returned, used the tooth-stick, performed ablution and again offered the prayer}}
\hadithdefcmd{muslim}{597}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ سُفْيَانَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا ابْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْفِطْرَةُ خَمْسٌ - أَوْ خَمْسٌ مِنَ الْفِطْرَةِ - الْخِتَانُ وَالاِسْتِحْدَادُ وَتَقْلِيمُ الأَظْفَارِ وَنَتْفُ الإِبْطِ وَقَصُّ الشَّارِبِ ‏"‏ ‏.‏\hadithno{597}\hadithtrans{Abu Huraira reported:Five are the acts quite akin to the Fitra, or five are the acts of Fitra: circumcision, shaving the pubes, cutting the nails, plucking the hair under the armpits and clipping the moustache}}
\hadithdefcmd{muslim}{598}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْفِطْرَةُ خَمْسٌ الاِخْتِتَانُ وَالاِسْتِحْدَادُ وَقَصُّ الشَّارِبِ وَتَقْلِيمُ الأَظْفَارِ وَنَتْفُ الإِبْطِ ‏"‏ ‏.‏\hadithno{598}\hadithtrans{Abu Huraira reported:Five are the acts of fitra: circumcision, removing the pubes, clipping the moustache, cutting the nails, plucking the hair under the armpits}}
\hadithdefcmd{muslim}{599}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ جَعْفَرٍ، - قَالَ يَحْيَى أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، - عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ أَنَسٌ وُقِّتَ لَنَا فِي قَصِّ الشَّارِبِ وَتَقْلِيمِ الأَظْفَارِ وَنَتْفِ الإِبْطِ وَحَلْقِ الْعَانَةِ أَنْ لاَ نَتْرُكَ أَكْثَرَ مِنْ أَرْبَعِينَ لَيْلَةً ‏.‏\hadithno{599}\hadithtrans{Anas reported:A time limit has been prescribed for us for clipping the moustache, cutting the nails, plucking hair under the armpits, shaving the pubes, that it should not be neglected far more than forty nights}}
\hadithdefcmd{muslim}{600}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى يَعْنِي ابْنَ سَعِيدٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحْفُوا الشَّوَارِبَ وَأَعْفُوا اللِّحَى ‏"‏ ‏.‏\hadithno{600}\hadithtrans{Ibn Umar said:The Apostle of Allah (ﷺ) said: Trim closely the moustache, and let the beard grow}}
\hadithdefcmd{muslim}{601}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَمَرَ بِإِحْفَاءِ الشَّوَارِبِ وَإِعْفَاءِ اللِّحْيَةِ ‏.‏\hadithno{601}\hadithtrans{Ibn Umar said:The Apostle of Allah (ﷺ) ordered us to trim the moustache closely and spare the beard}}
\hadithdefcmd{muslim}{602}{حَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ عُمَرَ بْنِ مُحَمَّدٍ، حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَالِفُوا الْمُشْرِكِينَ أَحْفُوا الشَّوَارِبَ وَأَوْفُوا اللِّحَى ‏"‏ ‏.‏\hadithno{602}\hadithtrans{Ibn Umar said:The Messenger of Allah (may peace be opon him) said: Act against the polytheists, trim closely the moustache and grow beard}}
\hadithdefcmd{muslim}{603}{حَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، مَوْلَى الْحُرَقَةِ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ جُزُّوا الشَّوَارِبَ وَأَرْخُوا اللِّحَى خَالِفُوا الْمَجُوسَ ‏"‏ ‏.‏\hadithno{603}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Trim closely the moustache, and grow beard, and thus act against the fire-worshippers}}
\hadithdefcmd{muslim}{604}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَشْرٌ مِنَ الْفِطْرَةِ قَصُّ الشَّارِبِ وَإِعْفَاءُ اللِّحْيَةِ وَالسِّوَاكُ وَاسْتِنْشَاقُ الْمَاءِ وَقَصُّ الأَظْفَارِ وَغَسْلُ الْبَرَاجِمِ وَنَتْفُ الإِبْطِ وَحَلْقُ الْعَانَةِ وَانْتِقَاصُ الْمَاءِ ‏"‏ ‏.‏ قَالَ زَكَرِيَّاءُ قَالَ مُصْعَبٌ وَنَسِيتُ الْعَاشِرَةَ إِلاَّ أَنْ تَكُونَ الْمَضْمَضَةَ ‏.‏ زَادَ قُتَيْبَةُ قَالَ وَكِيعٌ انْتِقَاصُ الْمَاءِ يَعْنِي الاِسْتِنْجَاءَ ‏.‏\hadithno{604}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) said: Ten are the acts according to fitra: clipping the moustache, letting the beard grow, using the tooth-stick, snuffing water in the nose, cutting the nails, washing the finger joints, plucking the hair under the armpits, shaving the pubes and cleaning one's private parts with water. The narrator said: I have forgotten the tenth, but it may have been rinsing the mouth}}
\hadithdefcmd{muslim}{605}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ مُصْعَبِ بْنِ شَيْبَةَ، فِي هَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ قَالَ أَبُوهُ وَنَسِيتُ الْعَاشِرَةَ ‏.‏\hadithno{605}\hadithtrans{This hadith has been narrated by Mus'ab b. Shaiba with the same chain of transmitters except for these words:" His father said: I forgot the tenth one}}
\hadithdefcmd{muslim}{606}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قِيلَ لَهُ قَدْ عَلَّمَكُمْ نَبِيُّكُمْ صلى الله عليه وسلم كُلَّ شَىْءٍ حَتَّى الْخِرَاءَةَ ‏.‏ قَالَ فَقَالَ أَجَلْ لَقَدْ نَهَانَا أَنْ نَسْتَقْبِلَ الْقِبْلَةَ لِغَائِطٍ أَوْ بَوْلٍ أَوْ أَنْ نَسْتَنْجِيَ بِالْيَمِينِ أَوْ أَنْ نَسْتَنْجِيَ بِأَقَلَّ مِنْ ثَلاَثَةِ أَحْجَارٍ أَوْ أَنْ نَسْتَنْجِيَ بِرَجِيعٍ أَوْ بِعَظْمٍ ‏.‏\hadithno{606}\hadithtrans{Salman reported that it was said to him:Your Apostle (ﷺ) teaches you about everything, even about excrement. He replied: Yes, he has forbidden us to face the Qibla at the time of excretion or urination, or cleansing with right hand or with less than three pebbles, or with dung or bone}}
\hadithdefcmd{muslim}{607}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، وَمَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَلْمَانَ، قَالَ قَالَ لَنَا الْمُشْرِكُونَ إِنِّي أَرَى صَاحِبَكُمْ يُعَلِّمُكُمْ حَتَّى يُعَلِّمَكُمُ الْخِرَاءَةَ ‏.‏ فَقَالَ أَجَلْ إِنَّهُ نَهَانَا أَنْ يَسْتَنْجِيَ أَحَدُنَا بِيَمِينِهِ أَوْ يَسْتَقْبِلَ الْقِبْلَةَ وَنَهَى عَنِ الرَّوْثِ وَالْعِظَامِ وَقَالَ ‏ "‏ لاَ يَسْتَنْجِي أَحَدُكُمْ بِدُونِ ثَلاَثَةِ أَحْجَارٍ ‏"‏ ‏.‏\hadithno{607}\hadithtrans{Salman said that (one among) the polytheists remarked:I see that your friend even teaches you about the excrement. He replied; Yes, he has in fact forbidden us that anyone amongst us should cleanse himself with his right hand, or face the Qibla. He has forbidden the use of dung or bone for it, and he has also instructed us not to use less than three pebbles (for this purpose)}}
\hadithdefcmd{muslim}{608}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَمَسَّحَ بِعَظْمٍ أَوْ بِبَعْرٍ ‏.‏\hadithno{608}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) forbade the use of bone or the droppings of camels for wiping (after excretion)}}
\hadithdefcmd{muslim}{609}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح قَالَ وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قُلْتُ لِسُفْيَانَ بْنِ عُيَيْنَةَ سَمِعْتَ الزُّهْرِيَّ، يَذْكُرُ عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَتَيْتُمُ الْغَائِطَ فَلاَ تَسْتَقْبِلُوا الْقِبْلَةَ وَلاَ تَسْتَدْبِرُوهَا بِبَوْلٍ وَلاَ غَائِطٍ وَلَكِنْ شَرِّقُوا أَوْ غَرِّبُوا ‏"‏ ‏.‏ قَالَ أَبُو أَيُّوبَ فَقَدِمْنَا الشَّامَ فَوَجَدْنَا مَرَاحِيضَ قَدْ بُنِيَتْ قِبَلَ الْقِبْلَةِ فَنَنْحَرِفُ عَنْهَا وَنَسْتَغْفِرُ اللَّهَ قَالَ نَعَمْ ‏.‏\hadithno{609}\hadithtrans{Abu Ayyub reported:The Apostle of Allah (ﷺ) said: Whenever you go to the desert, neither turn your face nor turn your back towards the Qibla while answering the call of nature, but face towards the east or the west. Abu Ayyub said: When we came to Syria we found that the latrines already built there were facing towards the Qibla. We turned our faces away from them and begged forgiveness of the Lord. He said: Yes}}
\hadithdefcmd{muslim}{610}{وَحَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، عَنِ الْقَعْقَاعِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَلَسَ أَحَدُكُمْ عَلَى حَاجَتِهِ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا ‏"‏ ‏.‏\hadithno{610}\hadithtrans{Abu Huraira said:When any one amongst you squats for answering the call of nature, he should neither turn his face towards the Qibla nor turn his back towards it}}
\hadithdefcmd{muslim}{611}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، قَالَ كُنْتُ أُصَلِّي فِي الْمَسْجِدِ وَعَبْدُ اللَّهِ بْنُ عُمَرَ مُسْنِدٌ ظَهْرَهُ إِلَى الْقِبْلَةِ فَلَمَّا قَضَيْتُ صَلاَتِي انْصَرَفْتُ إِلَيْهِ مِنْ شِقِّي فَقَالَ عَبْدُ اللَّهِ يَقُولُ نَاسٌ إِذَا قَعَدْتَ لِلْحَاجَةِ تَكُونُ لَكَ فَلاَ تَقْعُدْ مُسْتَقْبِلَ الْقِبْلَةِ وَلاَ بَيْتِ الْمَقْدِسِ - قَالَ عَبْدُ اللَّهِ - وَلَقَدْ رَقِيتُ عَلَى ظَهْرِ بَيْتٍ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاعِدًا عَلَى لَبِنَتَيْنِ مُسْتَقْبِلاً بَيْتَ الْمَقْدِسِ لِحَاجَتِهِ ‏.‏\hadithno{611}\hadithtrans{Wasi' b. Habban reported:I was offering my prayer in the mosque and Abdullah b. Umar was sitting there reclining with his back towards the Qibla. After completing my prayer. I went to him from one side. Abdullah said: People say when you go to the latrine, you should neither turn your face towards the Qibla nor towards Bait-ul-Maqdis. 'Abdullah said (farther): I went up to the roof of the house and saw the Messenger of Allah (ﷺ) squatting on two bricks for relieving himself with his face towards Bait-al-Maqdis}}
\hadithdefcmd{muslim}{612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنِ ابْنِ عُمَرَ، قَالَ رَقِيتُ عَلَى بَيْتِ أُخْتِي حَفْصَةَ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاعِدًا لِحَاجَتِهِ مُسْتَقْبِلَ الشَّامِ مُسْتَدْبِرَ الْقِبْلَةِ ‏.‏\hadithno{612}\hadithtrans{Abdullah b. Umar said:I went up to the roof of the house of my sister Hafsa and saw the Messenger of Allah (ﷺ) relieving himself facing Syria. with his back to the Qibla}}
\hadithdefcmd{muslim}{613}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ هَمَّامٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُمْسِكَنَّ أَحَدُكُمْ ذَكَرَهُ بِيَمِينِهِ وَهُوَ يَبُولُ وَلاَ يَتَمَسَّحْ مِنَ الْخَلاَءِ بِيَمِينِهِ وَلاَ يَتَنَفَّسْ فِي الإِنَاءِ ‏"‏ ‏.‏\hadithno{613}\hadithtrans{Abu Qatada reported it from his father:The Messenger of Allah (ﷺ) said: None of you should hold penis with his right hand while urinating, or wipe himself with his right hand in privy and should not breathe into the vessel (from which he drinks)}}
\hadithdefcmd{muslim}{614}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْخَلاَءَ فَلاَ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ ‏"‏ ‏.‏\hadithno{614}\hadithtrans{Abu Qatada reported it from his father that the Messenger of Allah (ﷺ) said:When anyone amongst you enters the privy he should not touch his penis with his right hand}}
\hadithdefcmd{muslim}{615}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَتَنَفَّسَ فِي الإِنَاءِ وَأَنْ يَمَسَّ ذَكَرَهُ بِيَمِينِهِ وَأَنْ يَسْتَطِيبَ بِيَمِينِهِ ‏.‏\hadithno{615}\hadithtrans{Aba Qatada reported:The Messenger of Allah (way peace be upon him) forbade (us) to breathe into the venel, to touch the penis with the right hand and to wipe after relieving with right hand}}
\hadithdefcmd{muslim}{616}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُحِبُّ التَّيَمُّنَ فِي طُهُورِهِ إِذَا تَطَهَّرَ وَفِي تَرَجُّلِهِ إِذَا تَرَجَّلَ وَفِي انْتِعَالِهِ إِذَا انْتَعَلَ ‏.‏\hadithno{616}\hadithtrans{A'isha reported:The Messenger of Allah (way peace be upon him) loved to start from the right-hand side for performing ablution, for combing (the hair) and wearing the shoes}}
\hadithdefcmd{muslim}{617}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الأَشْعَثِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ التَّيَمُّنَ فِي شَأْنِهِ كُلِّهِ فِي نَعْلَيْهِ وَتَرَجُّلِهِ وَطُهُورِهِ ‏.‏\hadithno{617}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) loved to start from the right-hand side in his every act i. e. in wearing shoes, in combing (his hair) and in performing ablution}}
\hadithdefcmd{muslim}{618}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اتَّقُوا اللَّعَّانَيْنِ ‏"‏ ‏.‏ قَالُوا وَمَا اللَّعَّانَانِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي يَتَخَلَّى فِي طَرِيقِ النَّاسِ أَوْ فِي ظِلِّهِمْ ‏"‏ ‏.‏\hadithno{618}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Be on your guard against two things which provoke cursing. They (the companions present there) said: Messenger of Allah, what are those things which provoke cursing? He said: Easing on the thoroughfares or under the shades (where they take shelter and rest)}}
\hadithdefcmd{muslim}{619}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ حَائِطًا وَتَبِعَهُ غُلاَمٌ مَعَهُ مِيضَأَةٌ هُوَ أَصْغَرُنَا فَوَضَعَهَا عِنْدَ سِدْرَةٍ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم حَاجَتَهُ فَخَرَجَ عَلَيْنَا وَقَدِ اسْتَنْجَى بِالْمَاءِ ‏.‏\hadithno{619}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) entered an enclosure while a servant was following him with a jar of water and he was the youngest amongst us and he placed it by the side of a lote-tree. When the Messenger of Allah, (ﷺ) relieved himself, he came out and had cleansed himself with water}}
\hadithdefcmd{muslim}{620}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَغُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ الْخَلاَءَ فَأَحْمِلُ أَنَا وَغُلاَمٌ نَحْوِي إِدَاوَةً مِنْ مَاءٍ وَعَنَزَةً فَيَسْتَنْجِي بِالْمَاءِ ‏.‏\hadithno{620}\hadithtrans{Anas b. Malik reported:When the Messenger of Allah (ﷺ) entered the privy, a servant and I used to carry a skin of water, and a pointed staff, and he would cleanse himself with water}}
\hadithdefcmd{muslim}{621}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لِزُهَيْرٍ - حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - حَدَّثَنِي رَوْحُ بْنُ الْقَاسِمِ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَبَرَّزُ لِحَاجَتِهِ فَآتِيهِ بِالْمَاءِ فَيَتَغَسَّلُ بِهِ ‏.‏\hadithno{621}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) went to a far-off place in the desert (hidden from the sight of human beings) for relieving himself. Then I brought water for him and he cleansed himself}}
\hadithdefcmd{muslim}{622}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، - وَاللَّفْظُ لِيَحْيَى - قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، قَالَ بَالَ جَرِيرٌ ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقِيلَ تَفْعَلُ هَذَا ‏.‏ فَقَالَ نَعَمْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَالَ ثُمَّ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ قَالَ الأَعْمَشُ قَالَ إِبْرَاهِيمُ كَانَ يُعْجِبُهُمْ هَذَا الْحَدِيثُ لأَنَّ إِسْلاَمَ جَرِيرٍ كَانَ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏\hadithno{622}\hadithtrans{Hummam reported:Jarir urinated, then performed ablution and wiped over the socks. It was said to him: Do you do like this? He said: Yes, I saw that the Messenger of Allah (ﷺ) urinated, then performed ablution and then wiped over his shoes. A'mash said: Ibrahim had observed that this hadith was a surprise for them (the people) because Jarir had embraced Islam after the revelation of Surat al-Ma'ida}}
\hadithdefcmd{muslim}{623}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ أَبِي عُمَرَ، قَالَ حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، كُلُّهُمْ عَنِ الأَعْمَشِ، فِي هَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِ أَبِي مُعَاوِيَةَ غَيْرَ أَنَّ فِي، حَدِيثِ عِيسَى وَسُفْيَانَ قَالَ فَكَانَ أَصْحَابُ عَبْدِ اللَّهِ يُعْجِبُهُمْ هَذَا الْحَدِيثُ لأَنَّ إِسْلاَمَ جَرِيرٍ كَانَ بَعْدَ نُزُولِ الْمَائِدَةِ ‏.‏\hadithno{623}\hadithtrans{This hadith is narrated on the same authority from A'mash by another chain of transmitters like one transmitted by Abu Mu'awyia. The hadith reported by 'Isa and Sufyan has these words also:" This hadith surprised the friends of Abdullab'" for Jarir had embraced Islam after the revelation of al-Ma'ida}}
\hadithdefcmd{muslim}{624}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَانْتَهَى إِلَى سُبَاطَةِ قَوْمٍ فَبَالَ قَائِمًا فَتَنَحَّيْتُ فَقَالَ ‏ "‏ ادْنُهْ ‏"‏ ‏.‏ فَدَنَوْتُ حَتَّى قُمْتُ عِنْدَ عَقِبَيْهِ فَتَوَضَّأَ فَمَسَحَ عَلَى خُفَّيْهِ ‏.‏\hadithno{624}\hadithtrans{Hudhaifa reported:I was with the Messenger of Allah (ﷺ) when he came to the dumping ground of filth belonging to a particular tribe. He urinated while standing, and I went aside. He (the Holy Prophet) asked me to come near him and I went so near to him that I stood behind his heels. He then performed ablution and wiped over his socks}}
\hadithdefcmd{muslim}{625}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ كَانَ أَبُو مُوسَى يُشَدِّدُ فِي الْبَوْلِ وَيَبُولُ فِي قَارُورَةٍ وَيَقُولُ إِنَّ بَنِي إِسْرَائِيلَ كَانَ إِذَا أَصَابَ جِلْدَ أَحَدِهِمْ بَوْلٌ قَرَضَهُ بِالْمَقَارِيضِ ‏.‏ فَقَالَ حُذَيْفَةُ لَوَدِدْتُ أَنَّ صَاحِبَكُمْ لاَ يُشَدِّدُ هَذَا التَّشْدِيدَ فَلَقَدْ رَأَيْتُنِي أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم نَتَمَاشَى فَأَتَى سُبَاطَةً خَلْفَ حَائِطٍ فَقَامَ كَمَا يَقُومُ أَحَدُكُمْ فَبَالَ فَانْتَبَذْتُ مِنْهُ فَأَشَارَ إِلَىَّ فَجِئْتُ فَقُمْتُ عِنْدَ عَقِبِهِ حَتَّى فَرَغَ ‏.‏\hadithno{625}\hadithtrans{Abu Wa'il reported:Abu Musa inflicted extreme rigour upon himself in the matter of urination and urinated in a bottle and said: When the skin of anyone amongst the people of Israel was besmeared with urine, he cut that portion with a cutter. Hudhaifa said: I wish that'your friend should not inflict such an extreme rigour. I and the Messenger of Allah (ﷺ) were going together till we reached the dumping ground of filth behind an enclosure. He stood up as one among you would stand up. and he urinated, I tried to turn away from him, but he beckoned to me, so I went to him and I stood behind him, till he had relieved himself}}
\hadithdefcmd{muslim}{626}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ خَرَجَ لِحَاجَتِهِ فَاتَّبَعَهُ الْمُغِيرَةُ بِإِدَاوَةٍ فِيهَا مَاءٌ فَصَبَّ عَلَيْهِ حِينَ فَرَغَ مِنْ حَاجَتِهِ فَتَوَضَّأَ وَمَسَحَ عَلَى الْخُفَّيْنِ ‏.‏ وَفِي رِوَايَةِ ابْنِ رُمْحٍ مَكَانَ حِينَ حَتَّى ‏.‏\hadithno{626}\hadithtrans{The son of Mughira b. Shu'ba reported:The Messenger of Allah (ﷺ) went out for relieving himself. Mughira went with him carrying a jug full of water. When he (the Holy Prophet) came back after relieving himself, he poured water over him and he performed ablution and wiped over his socks; and in the narration of Ibn Rumh there is" till" instead of" when}}
\hadithdefcmd{muslim}{627}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، بِهَذَا الإِسْنَادِ وَقَالَ فَغَسَلَ وَجْهَهُ وَيَدَيْهِ وَمَسَحَ بِرَأْسِهِ ثُمَّ مَسَحَ عَلَى الْخُفَّيْنِ ‏.‏\hadithno{627}\hadithtrans{This hadith has been transmitted with the same chain of transmitters by Yahya b. Sa'id with the addition of these words:" He washed his face and hands, and wiped his head and then wiped his socks}}
\hadithdefcmd{muslim}{628}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ بَيْنَا أَنَا مَعَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ إِذْ نَزَلَ فَقَضَى حَاجَتَهُ ثُمَّ جَاءَ فَصَبَبْتُ عَلَيْهِ مِنْ إِدَاوَةٍ كَانَتْ مَعِي فَتَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ‏.‏\hadithno{628}\hadithtrans{Mughira b. Shu'ba reported:I was with the Messenger of Allah (ﷺ) one night. He came down (from the ride) and relieved himself. He then came and I poured water upon him from the jar that I carried with me. He performed ablution and wiped over his socks}}
\hadithdefcmd{muslim}{629}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَقَالَ ‏ "‏ يَا مُغِيرَةُ خُذِ الإِدَاوَةَ ‏"‏ ‏.‏ فَأَخَذْتُهَا ثُمَّ خَرَجْتُ مَعَهُ فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى تَوَارَى عَنِّي فَقَضَى حَاجَتَهُ ثُمَّ جَاءَ وَعَلَيْهِ جُبَّةٌ شَامِيَّةٌ ضَيِّقَةُ الْكُمَّيْنِ فَذَهَبَ يُخْرِجُ يَدَهُ مِنْ كُمِّهَا فَضَاقَتْ عَلَيْهِ فَأَخْرَجَ يَدَهُ مِنْ أَسْفَلِهَا فَصَبَبْتُ عَلَيْهِ فَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ مَسَحَ عَلَى خُفَّيْهِ ثُمَّ صَلَّى ‏.‏\hadithno{629}\hadithtrans{Mughira b. Shu'ba reported:I was in the company of the Messenger of Allah (ﷺ) on a journey when he said: Mughira take hold of this jar (of water). I took hold of it and I went out with him. (I stopped but) the Messenger of Allah (ﷺ) proceeded on till he was out of my sight. He relieved himself and then came back and he was wearing a tight-sleeved Syrian gown. He tried to get his forearms out. but the sleeve of the gown was very narrow, so he brought his hands out from under the gown. I poured water over (his hands) and he performed ablution for prayer, then wiped over his socks and prayed}}
\hadithdefcmd{muslim}{630}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، جَمِيعًا عَنْ عِيسَى بْنِ يُونُسَ، - قَالَ إِسْحَاقُ أَخْبَرَنَا عِيسَى، - حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيَقْضِيَ حَاجَتَهُ فَلَمَّا رَجَعَ تَلَقَّيْتُهُ بِالإِدَاوَةِ فَصَبَبْتُ عَلَيْهِ فَغَسَلَ يَدَيْهِ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ لِيَغْسِلَ ذِرَاعَيْهِ فَضَاقَتِ الْجُبَّةُ فَأَخْرَجَهُمَا مِنْ تَحْتِ الْجُبَّةِ فَغَسَلَهُمَا وَمَسَحَ رَأْسَهُ وَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ صَلَّى بِنَا ‏.‏\hadithno{630}\hadithtrans{Mughira b. Shu'ba reported:The Messenger of Allah (ﷺ) went out for relieving himself. When he came back I brought for him a jar (of water) and poured water upon his hands and He washed his face. He tried to wash his forearms, but as the (sleeves of the) gown were tight. He, therefore, brought them out from under the gown. He then washed them, wiped his head, and wiped his socks and then prayed}}
\hadithdefcmd{muslim}{631}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الْمُغِيرَةِ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فِي مَسِيرٍ فَقَالَ لِي ‏"‏ أَمَعَكَ مَاءٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَنَزَلَ عَنْ رَاحِلَتِهِ فَمَشَى حَتَّى تَوَارَى فِي سَوَادِ اللَّيْلِ ثُمَّ جَاءَ فَأَفْرَغْتُ عَلَيْهِ مِنَ الإِدَاوَةِ فَغَسَلَ وَجْهَهُ وَعَلَيْهِ جُبَّةٌ مِنْ صُوفٍ فَلَمْ يَسْتَطِعْ أَنْ يُخْرِجَ ذِرَاعَيْهِ مِنْهَا حَتَّى أَخْرَجَهُمَا مِنْ أَسْفَلِ الْجُبَّةِ فَغَسَلَ ذِرَاعَيْهِ وَمَسَحَ بِرَأْسِهِ ثُمَّ أَهْوَيْتُ لأَنْزِعَ خُفَّيْهِ فَقَالَ ‏"‏ دَعْهُمَا فَإِنِّي أَدْخَلْتُهُمَا طَاهِرَتَيْنِ ‏"‏ ‏.‏ وَمَسَحَ عَلَيْهِمَا ‏.‏\hadithno{631}\hadithtrans{Urwa b. Mughira reported his father having said:I was one night with the Messenger of Allah (ﷺ) on a journey. He said to me: Have you any water with you? I said: Yes. He (the Holy Prophet) came down from his ride and went on till he disappeared in the darkness of night. He then came back and I poured water for him from the jar. He washed his face, He had a woollen gown on him and he could not bring out his forearms from it (i. e. from its sleeves) and consequently he brought them out from under his gown. He washed his forearms, wiped over his head. I then bent down to take off his socks. But he said: Leave them, for my feet were clean when I put them in, and he only wiped over them}}
\hadithdefcmd{muslim}{632}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عُمَرُ بْنُ أَبِي زَائِدَةَ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ، أَنَّهُ وَضَّأَ النَّبِيَّ صلى الله عليه وسلم فَتَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ فَقَالَ لَهُ فَقَالَ ‏ "‏ إِنِّي أَدْخَلْتُهُمَا طَاهِرَتَيْنِ ‏"‏ ‏.‏\hadithno{632}\hadithtrans{Urwah al Mughira reported it from his father:He (Mughira) helped the Apostle (ﷺ) in performing the ablution, and he performed it and wiped over his shoes. He (Mughira) said to him (about the washing of the feet after putting them off), but he (the Holy Prophet) said: I put them (feet) in when these were clean}}
\hadithdefcmd{muslim}{633}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، عَنْ عُرْوَةَ بْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ تَخَلَّفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَخَلَّفْتُ مَعَهُ فَلَمَّا قَضَى حَاجَتَهُ قَالَ ‏ "‏ أَمَعَكَ مَاءٌ ‏"‏ ‏.‏ فَأَتَيْتُهُ بِمَطْهَرَةٍ فَغَسَلَ كَفَّيْهِ وَوَجْهَهُ ثُمَّ ذَهَبَ يَحْسِرُ عَنْ ذِرَاعَيْهِ فَضَاقَ كُمُّ الْجُبَّةِ فَأَخْرَجَ يَدَهُ مِنْ تَحْتِ الْجُبَّةِ وَأَلْقَى الْجُبَّةَ عَلَى مَنْكِبَيْهِ وَغَسَلَ ذِرَاعَيْهِ وَمَسَحَ بِنَاصِيَتِهِ وَعَلَى الْعِمَامَةِ وَعَلَى خُفَّيْهِ ثُمَّ رَكِبَ وَرَكِبْتُ فَانْتَهَيْنَا إِلَى الْقَوْمِ وَقَدْ قَامُوا فِي الصَّلاَةِ يُصَلِّي بِهِمْ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ وَقَدْ رَكَعَ بِهِمْ رَكْعَةً فَلَمَّا أَحَسَّ بِالنَّبِيِّ صلى الله عليه وسلم ذَهَبَ يَتَأَخَّرُ فَأَوْمَأَ إِلَيْهِ فَصَلَّى بِهِمْ فَلَمَّا سَلَّمَ قَامَ النَّبِيُّ صلى الله عليه وسلم وَقُمْتُ فَرَكَعْنَا الرَّكْعَةَ الَّتِي سَبَقَتْنَا ‏.‏\hadithno{633}\hadithtrans{Urwa b. al Mughira b. Shu'ba reported it on the authority of his father that he said:The Messenger of Allah (ﷺ) lagged behind (in a journey) and I also lagged behind along with him. After having relieved himself he said: Have you any water with you? I brought to him a jar of water; he washed his palms, and face, and when he tried to get his forearms out (he could not) for the sleeve of the gown was tight. He, therefore, brought them out from under the gown and, throwing it over his shoulders, he washed his forearm. He then wiped his forelock and his turban and his socks. He then mounted and I also mounted (the ride) and came to the people. They had begun the prayer with 'Abd ar-Rabmin b. 'Anf leading them and had completed a rak'a. When he perceived the presence of the Messenger of Allah (ﷺ) he began to retire. He (the Holy Prophet) signed to him to continue and offered prayer along with them. Then when he had pronounced the salutation, the Apostle (ﷺ) got up and I also got up with him, and we offered the rak'a which had been finished before we came}}
\hadithdefcmd{muslim}{634}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي بَكْرُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَسَحَ عَلَى الْخُفَّيْنِ وَمُقَدَّمِ رَأْسِهِ وَعَلَى عِمَامَتِهِ ‏.‏\hadithno{634}\hadithtrans{Ibn Mughira narrated it from his father:The Apostle of Allah (ﷺ) wiped over his socks and over his forehead and over his turban}}
\hadithdefcmd{muslim}{635}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ بَكْرٍ، عَنِ الْحَسَنِ، عَنِ ابْنِ الْمُغِيرَةِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{635}\hadithtrans{This hadith has been transmitted by Ibn Mughira on the authority of his father by another chain of transmitters}}
\hadithdefcmd{muslim}{636}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، جَمِيعًا عَنْ يَحْيَى الْقَطَّانِ، قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ التَّيْمِيِّ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنِ ابْنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ أَبِيهِ، قَالَ بَكْرٌ وَقَدْ سَمِعْتُ مِنِ ابْنِ الْمُغِيرَةِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَمَسَحَ بِنَاصِيَتِهِ وَعَلَى الْعِمَامَةِ وَعَلَى الْخُفَّيْنِ ‏.‏\hadithno{636}\hadithtrans{Bakr reported that he had heard from the son of Mughira that verily the Messenger of Allah (ﷺ) performed ablution and wiped over his forehead and wiped over his turban and over his socks}}
\hadithdefcmd{muslim}{639}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ عَمْرِو بْنِ قَيْسٍ الْمُلاَئِيِّ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، قَالَ أَتَيْتُ عَائِشَةَ أَسْأَلُهَا عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَتْ عَلَيْكَ بِابْنِ أَبِي طَالِبٍ فَسَلْهُ فَإِنَّهُ كَانَ يُسَافِرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَسَأَلْنَاهُ فَقَالَ جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ لِلْمُسَافِرِ وَيَوْمًا وَلَيْلَةً لِلْمُقِيمِ ‏.‏ قَالَ وَكَانَ سُفْيَانُ إِذَا ذَكَرَ عَمْرًا أَثْنَى عَلَيْهِ ‏.‏\hadithno{639}\hadithtrans{Shuraih b. Hani said:I came to 'A'isha to ask her about wiping over the socks. She said: You better ask ('Ali) son of Abu Talib for he used to travel with Allah's Messenger (ﷺ). We asked him and he said: The Messenger of Allah (ﷺ) stipulated (the upper limit) of three days and three nights for a traveller and one day and one night for the resident}}
\hadithdefcmd{muslim}{640}{وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنِ الْحَكَمِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{640}\hadithtrans{This hadith is narrated by Ubaidullah b. 'Amr and Zaid b. Abu Unaisa with the same chain of transmitters}}
\hadithdefcmd{muslim}{641}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ شُرَيْحِ بْنِ هَانِئٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَتِ ائْتِ عَلِيًّا فَإِنَّهُ أَعْلَمُ بِذَلِكَ مِنِّي فَأَتَيْتُ عَلِيًّا فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{641}\hadithtrans{Shuraib b. Hani reported:I asked 'A'isha about wiping over the shoes. She said: You better go to 'Ali, for he knows more about this than I. I, therefore, came to 'Ali and he narrated from the Apostle (ﷺ) like this}}
\hadithdefcmd{muslim}{642}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الصَّلَوَاتِ يَوْمَ الْفَتْحِ بِوُضُوءٍ وَاحِدٍ وَمَسَحَ عَلَى خُفَّيْهِ فَقَالَ لَهُ عُمَرُ لَقَدْ صَنَعْتَ الْيَوْمَ شَيْئًا لَمْ تَكُنْ تَصْنَعُهُ ‏.‏ قَالَ ‏ "‏ عَمْدًا صَنَعْتُهُ يَا عُمَرُ ‏"‏ ‏.‏\hadithno{642}\hadithtrans{Sulaiman b. Buraida narrated it from his father that the Messenger of Allah (ﷺ) offered prayers with one ablution on the day of the Conquest (of Mecca) and wiped over the socks. 'Umar said to him:You have today done something that you have not been accustomed to before. He (the Holy Prophet) said: 0 'Umar, I have done that on purpose}}
\hadithdefcmd{muslim}{643}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَحَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، قَالاَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ مِنْ نَوْمِهِ فَلاَ يَغْمِسْ يَدَهُ فِي الإِنَاءِ حَتَّى يَغْسِلَهَا ثَلاَثًا فَإِنَّهُ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{643}\hadithtrans{Abu Huraira said:When anyone amongst you wakes up from sleep, he must not put his hand in the utensil till he has washed it three times, for he does not know where his hand was during the night}}
\hadithdefcmd{muslim}{644}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، فِي حَدِيثِ أَبِي مُعَاوِيَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَفِي حَدِيثِ وَكِيعٍ قَالَ يَرْفَعُهُ بِمِثْلِهِ ‏.‏\hadithno{644}\hadithtrans{This hadith is transmitted from Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{645}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، ح وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، كِلاَهُمَا عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{645}\hadithtrans{Zahri and Ibn Musayyab have both transmitted a hadith like this from Abu Huraira who narrated it from the Apostle (ﷺ)}}
\hadithdefcmd{muslim}{646}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَيْقَظَ أَحَدُكُمْ فَلْيُفْرِغْ عَلَى يَدِهِ ثَلاَثَ مَرَّاتٍ قَبْلَ أَنْ يُدْخِلَ يَدَهُ فِي إِنَائِهِ فَإِنَّهُ لاَ يَدْرِي فِيمَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{646}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said: When anyone amongst you wakes up from sleep, he should wash his hands three times before putting it in the utensil, for he does not know where his hand was during the night}}
\hadithdefcmd{muslim}{647}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنِي أَبُو كُرَيْبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ مَخْلَدٍ - عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح وَحَدَّثَنَا الْحُلْوَانِيُّ، وَابْنُ، رَافِعٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالاَ جَمِيعًا أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي زِيَادٌ، أَنَّ ثَابِتًا، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زَيْدٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، فِي رِوَايَتِهِمْ جَمِيعًا عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ كُلُّهُمْ يَقُولُ حَتَّى يَغْسِلَهَا ‏.‏ وَلَمْ يَقُلْ وَاحِدٌ مِنْهُمْ ثَلاَثًا ‏.‏ إِلاَّ مَا قَدَّمْنَا مِنْ رِوَايَةِ جَابِرٍ وَابْنِ الْمُسَيَّبِ وَأَبِي سَلَمَةَ وَعَبْدِ اللَّهِ بْنِ شَقِيقٍ وَأَبِي صَالِحٍ وَأَبِي رَزِينٍ فَإِنَّ فِي حَدِيثِهِمْ ذِكْرَ الثَّلاَثِ ‏.‏\hadithno{647}\hadithtrans{This hadith has been transmitted through other chains of transmitters on the authority of Abu Huraira in which it is reported that the Messenger of Allah (ﷺ) made a mention of washing the hand, and did not instruct to wash it three times. But the hadith narrated from Jabir and Ibn Musayyab. Abu Salama, and Abdullah b. Shaqiq, Abu Salih, Abla Razin, there is a mention of" three times}}
\hadithdefcmd{muslim}{648}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا الأَعْمَشُ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيُرِقْهُ ثُمَّ لْيَغْسِلْهُ سَبْعَ مِرَارٍ ‏"‏ ‏.‏\hadithno{648}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) to have said:When a dog licks a utensil belonging to any one of you, (the thing contained in it) should be thrown away and then (the utensil) should be washed seven times}}
\hadithdefcmd{muslim}{649}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَقُلْ فَلْيُرِقْهُ ‏.‏\hadithno{649}\hadithtrans{This hadith has been transmitted by another chain of transmitters in which there is no mention of" throwing away}}
\hadithdefcmd{muslim}{650}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{650}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When a dog drinks out of a vessel belonging to any one of you, he must wash it seven times}}
\hadithdefcmd{muslim}{651}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامِ بْنِ حَسَّانٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طُهُورُ إِنَاءِ أَحَدِكُمْ إِذَا وَلَغَ فِيهِ الْكَلْبُ أَنْ يَغْسِلَهُ سَبْعَ مَرَّاتٍ أُولاَهُنَّ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{651}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: The purification of the utensil belonging to any one of you, after it is licked by a dog, lies in washing it seven times, using sand for the first time}}
\hadithdefcmd{muslim}{652}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ طُهُورُ إِنَاءِ أَحَدِكُمْ إِذَا وَلَغَ الْكَلْبُ فِيهِ أَنْ يَغْسِلَهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{652}\hadithtrans{Hammam b. Munabbih reported:Of the a hadith narrated by Abu Huraira from Muhammad, the Messenger of Allah (ﷺ), one is this: The Messenger of Allah (ﷺ) said: The purification of the utensil belonging to one amongst you, after it is licked by a dog, lies in washing it seven times}}
\hadithdefcmd{muslim}{653}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، سَمِعَ مُطَرِّفَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنِ ابْنِ الْمُغَفَّلِ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ ثُمَّ قَالَ ‏"‏ مَا بَالُهُمْ وَبَالُ الْكِلاَبِ ‏"‏ ‏.‏ ثُمَّ رَخَّصَ فِي كَلْبِ الصَّيْدِ وَكَلْبِ الْغَنَمِ وَقَالَ ‏"‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ وَعَفِّرُوهُ الثَّامِنَةَ فِي التُّرَابِ ‏"‏ ‏.‏\hadithno{653}\hadithtrans{Ibn Mughaffal reported:The Messenger of Allah (ﷺ) ordered killing of the dogs, and then said: What about them, i. e. about other dogs? and then granted concession (to keep) the dog for hunting and the dog for (the security) of the herd, and said: When the dog licks the utensil, wash it seven times, and rub it with earth the eighth time}}
\hadithdefcmd{muslim}{654}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، كُلُّهُمْ عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ غَيْرَ أَنَّ فِي رِوَايَةِ يَحْيَى بْنِ سَعِيدٍ مِنَ الزِّيَادَةِ وَرَخَّصَ فِي كَلْبِ الْغَنَمِ وَالصَّيْدِ وَالزَّرْعِ وَلَيْسَ ذَكَرَ الزَّرْعَ فِي الرِّوَايَةِ غَيْرُ يَحْيَى ‏.‏\hadithno{654}\hadithtrans{A hadith like this has been narrated from Shu'ba with the same chain of transmitters except for the fact that in the hadith transmitted by Yahya those words are:" He (the Holy Prophet) gave concession in the case of the dog for looking after the herd, for hunting and for watching the cultivated land," and there is no mention of this addition (i. e. concession in case of watching the cultivated lands) except in the hadith transmitted by Yahya}}
\hadithdefcmd{muslim}{655}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُبَالَ فِي الْمَاءِ الرَّاكِدِ ‏.‏\hadithno{655}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) forbade to urinate in stagnant water}}
\hadithdefcmd{muslim}{656}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَغْتَسِلُ مِنْهُ ‏"‏ ‏.‏\hadithno{656}\hadithtrans{Abu Huraira reported:the Messenger of Allah (ﷺ) said: None amongst you should urinate in standing water, and then wash in it}}
\hadithdefcmd{muslim}{657}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبُلْ فِي الْمَاءِ الدَّائِمِ الَّذِي لاَ يَجْرِي ثُمَّ تَغْتَسِلُ مِنْهُ ‏"‏ ‏.‏\hadithno{657}\hadithtrans{Hammam b. Munabbih said:Of the ahadith narrated to us by Abfi Huraira from Muhammad the Messenger of Allah (ﷺ) one is this: The Messenger or Allah (ﷺ) said: You should not urinate in standing water, that is not flowing, then wash in it}}
\hadithdefcmd{muslim}{658}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَبُو الطَّاهِرِ، وَأَحْمَدُ بْنُ عِيسَى، جَمِيعًا عَنِ ابْنِ وَهْبٍ، - قَالَ هَارُونُ حَدَّثَنَا ابْنُ وَهْبٍ، - أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، أَنَّ أَبَا السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغْتَسِلُ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَهُوَ جُنُبٌ ‏"‏ ‏.‏ فَقَالَ كَيْفَ يَفْعَلُ يَا أَبَا هُرَيْرَةَ قَالَ يَتَنَاوَلُهُ تَنَاوُلاً ‏.‏\hadithno{658}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) saying:None of you must wash in standing water when he is in a state of Junub. And Abu Huraira was asked how it was to be done; he said: It was to be taken out in handfuls}}
\hadithdefcmd{muslim}{659}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أَعْرَابِيًّا، بَالَ فِي الْمَسْجِدِ فَقَامَ إِلَيْهِ بَعْضُ الْقَوْمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ وَلاَ تُزْرِمُوهُ ‏"‏ ‏.‏ قَالَ فَلَمَّا فَرَغَ دَعَا بِدَلْوٍ مِنْ مَاءٍ فَصَبَّهُ عَلَيْهِ ‏.‏\hadithno{659}\hadithtrans{Anas reported:A Bedouin urinated in the mosque. Some of the persons stood up (to reprimand him or to check him from doing so), but the Messenger of Allah (ﷺ) said: Leave him alone; don't interrupt him. He (the narrator) said: And when he had finished, he called for a bucket of water and poured it over}}
\hadithdefcmd{muslim}{660}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنِ الدَّرَاوَرْدِيِّ، - قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الْمَدَنِيُّ، - عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَذْكُرُ أَنَّ أَعْرَابِيًّا، قَامَ إِلَى نَاحِيَةٍ فِي الْمَسْجِدِ فَبَالَ فِيهَا فَصَاحَ بِهِ النَّاسُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَنُوبٍ فَصُبَّ عَلَى بَوْلِهِ ‏.‏\hadithno{660}\hadithtrans{Anas b. Malik narrated that a desert Arab (Bedouin) stood in a corner of the mosque and urinated there. The people (the Companions of the Prophet who were present there) shouted, but the Messenger of Allah (ﷺ) said:Leave him alone. When he had finished, the Messenger of Allah (ﷺ) ordered that a bucket (of water) should be brought and poured over it}}
\hadithdefcmd{muslim}{661}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْحَاقُ بْنُ أَبِي طَلْحَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، - وَهُوَ عَمُّ إِسْحَاقَ - قَالَ بَيْنَمَا نَحْنُ فِي الْمَسْجِدِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَ أَعْرَابِيٌّ فَقَامَ يَبُولُ فِي الْمَسْجِدِ فَقَالَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم مَهْ مَهْ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُزْرِمُوهُ دَعُوهُ ‏"‏ ‏.‏ فَتَرَكُوهُ حَتَّى بَالَ ‏.‏ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَاهُ فَقَالَ لَهُ ‏"‏ إِنَّ هَذِهِ الْمَسَاجِدَ لاَ تَصْلُحُ لِشَىْءٍ مِنْ هَذَا الْبَوْلِ وَلاَ الْقَذَرِ إِنَّمَا هِيَ لِذِكْرِ اللَّهِ عَزَّ وَجَلَّ وَالصَّلاَةِ وَقِرَاءَةِ الْقُرْآنِ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَأَمَرَ رَجُلاً مِنَ الْقَوْمِ فَجَاءَ بِدَلْوٍ مِنْ مَاءٍ فَشَنَّهُ عَلَيْهِ ‏.‏\hadithno{661}\hadithtrans{Anas b. Malik reported:While we were in the mosque with Allah's Messenger (ﷺ), a desert Arab came and stood up and began to urinate in the mosque. The Companions of Allah's Messenger (ﷺ) said: Stop, stop, but the Messenger of Allah (ﷺ) said: Don't interrupt him; leave him alone. They left him alone, and when he finished urinating, Allah's Messenger (ﷺ) called him and said to him: These mosques are not the places meant for urine and filth, but are only for the remembrance of Allah, prayer and the recitation of the Qur'an, or Allah's Messenger said something like that. He (the narrator) said that he (the Holy Prophet) then gave orders to one of the people who brought a bucket of water and poured It over}}
\hadithdefcmd{muslim}{662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالصِّبْيَانِ فَيُبَرِّكُ عَلَيْهِمْ وَيُحَنِّكُهُمْ فَأُتِيَ بِصَبِيٍّ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَأَتْبَعَهُ بَوْلَهُ وَلَمْ يَغْسِلْهُ ‏.‏\hadithno{662}\hadithtrans{A'isha, the wife of the Apostle (ﷺ) said:Babies were brought to the Messenger of Allah (ﷺ) and he blessed them, and after having chewed (something, e. g. dates or any other sweet thing) he rubbed there with their soft palates. A baby was brought to him and he passed water over him (over his garment), so he asked water to be brought and sprinkled it, but he did not wash it}}
\hadithdefcmd{muslim}{663}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَبِيٍّ يَرْضَعُ فَبَالَ فِي حِجْرِهِ فَدَعَا بِمَاءٍ فَصَبَّهُ عَلَيْهِ ‏.‏\hadithno{663}\hadithtrans{A'isha reported:A suckling babe was brought to the Messenger of Allah (way peace be upon him) and he urinated in his tap. He (the Holy Prophet) sent for water and poured it over}}
\hadithdefcmd{muslim}{664}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ مِثْلَ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{664}\hadithtrans{Hisham narrated the hadith like one transmitted by Ibn Numair (the above mentioned one) with the same chain of transmitters}}
\hadithdefcmd{muslim}{665}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا لَمْ يَأْكُلِ الطَّعَامَ فَوَضَعَتْهُ فِي حِجْرِهِ فَبَالَ - قَالَ - فَلَمْ يَزِدْ عَلَى أَنْ نَضَحَ بِالْمَاءِ ‏.‏\hadithno{665}\hadithtrans{Umm Qais daughter of Mihsan reported that she came to the Messenger of Allah (ﷺ) with her child. who was not yet weaned, and she placed him in his lap; and he urinated in his (Holy Prophet's) lap. He (the Holy Prophet) did nothing more than spraying water over it}}
\hadithdefcmd{muslim}{666}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَقَالَ فَدَعَا بِمَاءٍ فَرَشَّهُ ‏.‏\hadithno{666}\hadithtrans{This hadith has also been narrated from al-Zuhri with the same chain of narrators. (but for the words):" He (the Holy Prophet) sent for water and sprinkled it over}}
\hadithdefcmd{muslim}{667}{وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، - وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهِيَ أُخْتُ عُكَّاشَةَ بْنِ مِحْصَنٍ أَحَدُ بَنِي أَسَدِ بْنِ خُزَيْمَةَ - قَالَ أَخْبَرَتْنِي أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا لَمْ يَبْلُغْ أَنْ يَأْكُلَ الطَّعَامَ - قَالَ عُبَيْدُ اللَّهِ - أَخْبَرَتْنِي أَنَّ ابْنَهَا ذَاكَ بَالَ فِي حِجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَنَضَحَهُ عَلَى ثَوْبِهِ وَلَمْ يَغْسِلْهُ غَسْلاً ‏.‏\hadithno{667}\hadithtrans{Ubaidullah b. Abdullah b. 'Utba b. Mas'ud said:Umm Qais, daughter of Mihsan, was among the earliest female emigrants who took the oath of allegiance to the Messenger of Allah (ﷺ), and she was the sister of 'Ukkasha b. Mihsan, one amongst the sons of Asad b. Khuzaima. He (the narrator) said: She (Umm Qais) told me that she came to the Messenger of Allah (may peace he upon him) with her son and he had not attained the age of eating food. He (the narrator, 'Ubaidullah), said: She told me that her son passed urine in the lap of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) sent for water and sprayed it over his garment (over that part which was contaminated with the urine of the child) and he did not wash it thoroughly}}
\hadithdefcmd{muslim}{668}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، أَنَّ رَجُلاً، نَزَلَ بِعَائِشَةَ فَأَصْبَحَ يَغْسِلُ ثَوْبَهُ فَقَالَتْ عَائِشَةُ إِنَّمَا كَانَ يُجْزِئُكَ إِنْ رَأَيْتَهُ أَنْ تَغْسِلَ مَكَانَهُ فَإِنْ لَمْ تَرَ نَضَحْتَ حَوْلَهُ وَلَقَدْ رَأَيْتُنِي أَفْرُكُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرْكًا فَيُصَلِّي فِيهِ ‏.‏\hadithno{668}\hadithtrans{Alqama and Aswad reported:A person stayed in the house of A'isha and in the morning began to wash his garment. A'isha said: In case you saw it (i. e. drop of semen), it would have served the purpose (of purifying the garment) if you had simply washed that spot; and in case you did not see it, it would have been enough to sprinkle water around it, for when I saw that on the garment of the Messenger of Allah (ﷺ). I simply scraped it off and he offered prayer, while putting that on}}
\hadithdefcmd{muslim}{669}{وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَهَمَّامٍ، عَنْ عَائِشَةَ، فِي الْمَنِيِّ قَالَتْ كُنْتُ أَفْرُكُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{669}\hadithtrans{Al-Aawad and Hammam reported A'isha as saying:I used to scrape off the (drop of) semen from the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{670}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ هِشَامِ بْنِ حَسَّانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا ابْنُ أَبِي عَرُوبَةَ، جَمِيعًا عَنْ أَبِي مَعْشَرٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُغِيرَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَهْدِيِّ بْنِ مَيْمُونٍ، عَنْ وَاصِلٍ الأَحْدَبِ، ح وَحَدَّثَنِي ابْنُ حَاتِمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، وَمُغِيرَةَ، كُلُّ هَؤُلاَءِ عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، فِي حَتِّ الْمَنِيِّ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَحْوَ حَدِيثِ خَالِدٍ عَنْ أَبِي مَعْشَرٍ ‏.‏\hadithno{670}\hadithtrans{Qutaiba b. Sa'id, Ishaq b. Ibrahim, Ibn Abi 'Aruba, Abu Ma'shar, Abu Bakr b. Abu Shaiba, Mansur and Mughira have all transmitted from Ibrahim, who transmitted it on the authority of A'isha's narration pertaining to the scraping off of the (drop) of semen from the garment of the Messenger of Allah (ﷺ) like the hadith of Khalid on the authority of Abu Ma'shar}}
\hadithdefcmd{muslim}{671}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَائِشَةَ، بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{671}\hadithtrans{Hammam narrated the hadith from A'isha like the (above-mentioned) traditions}}
\hadithdefcmd{muslim}{672}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، قَالَ سَأَلْتُ سُلَيْمَانَ بْنَ يَسَارٍ عَنِ الْمَنِيِّ، يُصِيبُ ثَوْبَ الرَّجُلِ أَيَغْسِلُهُ أَمْ يَغْسِلُ الثَّوْبَ فَقَالَ أَخْبَرَتْنِي عَائِشَةُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْسِلُ الْمَنِيَّ ثُمَّ يَخْرُجُ إِلَى الصَّلاَةِ فِي ذَلِكَ الثَّوْبِ وَأَنَا أَنْظُرُ إِلَى أَثَرِ الْغَسْلِ فِيهِ ‏.‏\hadithno{672}\hadithtrans{Amr b. Maimun said:I asked Sulaiman b. Yasar whether the semen that gets on to the garment of a person should be washed or not. He replied: A'isha told me: The Messenger of Allah (ﷺ) washed the semen, and then went out for prayer in that very garment and I saw the mark of washing on it}}
\hadithdefcmd{muslim}{673}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، وَابْنُ أَبِي زَائِدَةَ، كُلُّهُمْ عَنْ عَمْرِو بْنِ مَيْمُونٍ، بِهَذَا الإِسْنَادِ أَمَّا ابْنُ أَبِي زَائِدَةَ فَحَدِيثُهُ كَمَا قَالَ ابْنُ بِشْرٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْسِلُ الْمَنِيَّ وَأَمَّا ابْنُ الْمُبَارَكِ وَعَبْدُ الْوَاحِدِ فَفِي حَدِيثِهِمَا قَالَتْ كُنْتُ أَغْسِلُهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{673}\hadithtrans{Abu Kuraib, Ibn al-Mubarak, Ibn Abu Za'ida all of them narrated from Amr b. Maimun with the same chain of transmitters. Ibn Abu Za'ida narrated as was transmitted from Ibn Bishr that the Messenger of Allah (ﷺ) washed semen, and in the hadith transmitted on the authority of Ibn Mabarak and Abdul Wahid the words are:" She (A'isha) reported: I used to wash it from the garment of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{674}{وَحَدَّثَنَا أَحْمَدُ بْنُ جَوَّاسٍ الْحَنَفِيُّ أَبُو عَاصِمٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شِهَابٍ الْخَوْلاَنِيِّ، قَالَ كُنْتُ نَازِلاً عَلَى عَائِشَةَ فَاحْتَلَمْتُ فِي ثَوْبَىَّ فَغَمَسْتُهُمَا فِي الْمَاءِ فَرَأَتْنِي جَارِيَةٌ لِعَائِشَةَ فَأَخْبَرَتْهَا فَبَعَثَتْ إِلَىَّ عَائِشَةُ فَقَالَتْ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ بِثَوْبَيْكَ قَالَ قُلْتُ رَأَيْتُ مَا يَرَى النَّائِمُ فِي مَنَامِهِ ‏.‏ قَالَتْ هَلْ رَأَيْتَ فِيهِمَا شَيْئًا ‏.‏ قُلْتُ لاَ ‏.‏ قَالَتْ فَلَوْ رَأَيْتَ شَيْئًا غَسَلْتَهُ لَقَدْ رَأَيْتُنِي وَإِنِّي لأَحُكُّهُ مِنْ ثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَابِسًا بِظُفُرِي ‏.‏\hadithno{674}\hadithtrans{Abdullah b. Shihab al-Khaulani reported:I stayed in the house of 'A'isha and had a wet dream (and perceived its effect on my garment), so (in the morning) I dipped both (the clothes) in water. This (act of mine) was watched by a maid-servant of A'isha and she informed her. She (Hadrat A'isha) sent me a message: Whatprompted you to act like this with your clothes? He (the narrator) said: I told that I saw in a dream what a sleeper sees. She said: Did you find (any mark of the fluid) on your clothes? I said: No. She said: Had you found anything you should have washed it. Incase I found that (semen) on the garment of the Messenger of Allah (ﷺ) dried up, I scraped it off with my nails}}
\hadithdefcmd{muslim}{675}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ حَدَّثَتْنِي فَاطِمَةُ، عَنْ أَسْمَاءَ، قَالَتْ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِحْدَانَا يُصِيبُ ثَوْبَهَا مِنْ دَمِ الْحَيْضَةِ كَيْفَ تَصْنَعُ بِهِ قَالَ ‏ "‏ تَحُتُّهُ ثُمَّ تَقْرُصُهُ بِالْمَاءِ ثُمَّ تَنْضَحُهُ ثُمَّ تُصَلِّي فِيهِ ‏"‏ ‏.‏\hadithno{675}\hadithtrans{Asma (daughter of Abu Bakr) reported:A woman came to the Messenger of Allah (ﷺ) and said: What should one do if the blood of menses smears the garment of one amongst us? He (the Holy Prophet) replied: She should scrape it, then rub it with water, then pour water over it and then offer prayer in it}}
\hadithdefcmd{muslim}{676}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ سَالِمٍ، وَمَالِكُ بْنُ أَنَسٍ، وَعَمْرُو بْنُ الْحَارِثِ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ مِثْلَ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ ‏.‏\hadithno{676}\hadithtrans{This tradition is narrated by Abu Kuraib, Ibn Numair, Abu Tahir, Ibn Wahb, Yahya b. 'Abdullah b. Salim, Malik b. Anas, 'Amr b. Harith on the authority of Hisham b. 'Urwa, with the same chain of transmitters like one transmitted by Yahya b. Sa'id like the above-mentioned}}
\hadithdefcmd{muslim}{677}{وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى قَبْرَيْنِ فَقَالَ ‏"‏ أَمَا إِنَّهُمَا لَيُعَذَّبَانِ وَمَا يُعَذَّبَانِ فِي كَبِيرٍ أَمَّا أَحَدُهُمَا فَكَانَ يَمْشِي بِالنَّمِيمَةِ وَأَمَّا الآخَرُ فَكَانَ لاَ يَسْتَتِرُ مِنْ بَوْلِهِ ‏"‏ ‏.‏ قَالَ فَدَعَا بِعَسِيبٍ رَطْبٍ فَشَقَّهُ بِاثْنَيْنِ ثُمَّ غَرَسَ عَلَى هَذَا وَاحِدًا وَعَلَى هَذَا وَاحِدًا ثُمَّ قَالَ ‏"‏ لَعَلَّهُ أَنْ يُخَفَّفَ عَنْهُمَا مَا لَمْ يَيْبَسَا ‏"‏ ‏.‏\hadithno{677}\hadithtrans{Ibn Abbas reported:The Messenger of Allah (ﷺ) happened to pass by two graves and said: They (their occupants) are being tormented, but they are not tormented for a grievous sin. One of them carried tales and the other did not keep himself safe from being defiled by urine. He then called for a fresh twig and split it into two parts, and planted them on each grave and then said: Perhaps, their punishment way be mitigated as long as these twigs remain fresh}}
\hadithdefcmd{muslim}{678}{حَدَّثَنِيهِ أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنْ سُلَيْمَانَ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَكَانَ الآخَرُ لاَ يَسْتَنْزِهُ عَنِ الْبَوْلِ أَوْ مِنَ الْبَوْلِ ‏"‏ ‏.‏\hadithno{678}\hadithtrans{This hadith is transmitted from A'mash by Abmad b. Yusuf al-Azdi, Mu'alla b. Asad, Abd al-Wahid, Sulaiman with the same chain of transmitters but for the words:" The other did not keep himself safe from being defiled by urine}}
